@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,6 +27,7 @@
 #include "provider-config.h"
 #include "gdaui-dsn-assistant.h"
 
+GtkApplication *app;
 GtkWindow *main_window;
 GtkActionGroup *actions;
 
@@ -141,7 +143,7 @@ file_delete_cb (G_GNUC_UNUSED GtkAction *action, gpointer user_data)
 static void
 window_closed_cb (G_GNUC_UNUSED GtkAction *action, G_GNUC_UNUSED gpointer user_data)
 {
-	gtk_main_quit ();
+	g_application_quit (G_APPLICATION (app));
 }
 
 static void
@@ -260,7 +262,7 @@ create_main_window (void)
 	GdkPixbuf *icon;
 
 	/* create the main window */
-	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	window = gtk_application_window_new (app);
 	main_window = GTK_WINDOW (window);
 	gtk_window_set_title (GTK_WINDOW (window), _("Database access control center"));
 	gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
@@ -279,7 +281,7 @@ create_main_window (void)
 	}
 
 	/* menu and contents */
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add (GTK_CONTAINER (window), vbox);
 	gtk_widget_show (vbox);
 
@@ -310,7 +312,6 @@ activate (GtkApplication *app)
 int
 main (int argc, char *argv[])
 {
-	GtkApplication *app;
 	gint status;
 	
 	app = gtk_application_new ("org.GnomeDb.GdaBrowser", G_APPLICATION_FLAGS_NONE);
@@ -324,7 +325,7 @@ main (int argc, char *argv[])
 }
 
 static void
-dsn_selection_changed_cb (GdauiRawGrid *dbrawgrid, gboolean row_selected, G_GNUC_UNUSED gpointer data)
+dsn_selection_changed_cb (GdauiRawGrid *dbrawgrid, G_GNUC_UNUSED gboolean row_selected, G_GNUC_UNUSED gpointer data)
 {
 	GtkAction *action;
 	GArray *selection;
