@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,9 +20,11 @@
  */
 
 #include <libgda/libgda.h>
+#include <glib/gi18n-lib.h>
 #include "gdaui-entry-combo.h"
 #include "gdaui-combo.h"
 #include "gdaui-data-store.h"
+#include <libgda/gda-debug-macros.h>
 
 static void gdaui_entry_combo_class_init (GdauiEntryComboClass *class);
 static void gdaui_entry_combo_init (GdauiEntryCombo *wid);
@@ -52,7 +55,6 @@ static const GValue   *gdaui_entry_combo_get_ref_value     (GdauiDataEntry *de);
 static void            gdaui_entry_combo_set_value_default (GdauiDataEntry *de, const GValue * value);
 static void            gdaui_entry_combo_set_attributes    (GdauiDataEntry *de, guint attrs, guint mask);
 static GdaValueAttribute gdaui_entry_combo_get_attributes    (GdauiDataEntry *de);
-static gboolean        gdaui_entry_combo_can_expand  (GdauiDataEntry *de, gboolean horiz);
 static void            gdaui_entry_combo_grab_focus        (GdauiDataEntry *de);
 static void            gdaui_entry_combo_set_unknown_color (GdauiDataEntry *de, gdouble red, gdouble green,
 							    gdouble blue, gdouble alpha);
@@ -70,10 +72,10 @@ enum {
  * used.
  */
 typedef struct {
-	GdaSetNode *node;
-	const GValue       *value;    /* we don't own the value, since it belongs to a GdaDataModel => don't free it */
-	GValue             *value_orig;
-	GValue             *value_default;
+	GdaSetNode   *node;
+	GValue       *value;
+	GValue       *value_orig;
+	GValue       *value_default;
 } ComboNode;
 #define COMBO_NODE(x) ((ComboNode*)(x))
 
@@ -142,7 +144,6 @@ gdaui_entry_combo_data_entry_init (GdauiDataEntryIface *iface)
         iface->set_attributes = gdaui_entry_combo_set_attributes;
         iface->get_attributes = gdaui_entry_combo_get_attributes;
         iface->get_handler = NULL;
-        iface->can_expand = gdaui_entry_combo_can_expand;
 	iface->grab_focus = gdaui_entry_combo_grab_focus;
 	iface->set_unknown_color = gdaui_entry_combo_set_unknown_color;
 }
@@ -241,15 +242,17 @@ uiset_source_model_changed_cb (G_GNUC_UNUSED GdauiSet *paramlist, GdauiSetSource
 {
 	if (source == combo->priv->source) {
 		GSList *list, *values = NULL;
-		for (list = source->source->nodes; list; list = list->next) {
+		GdaSetSource *s;
+		s = gdaui_set_source_get_source (source);
+		for (list = gda_set_source_get_nodes (s); list; list = list->next) {
 			const GValue *cvalue;
-			cvalue = gda_holder_get_value (GDA_SET_NODE (list->data)->holder);
+			cvalue = gda_holder_get_value (gda_set_node_get_holder (GDA_SET_NODE (list->data)));
 			values = g_slist_append (values, (GValue *) cvalue);
 		}
 		gdaui_combo_set_model (GDAUI_COMBO (combo->priv->combo_entry),
-				       source->source->data_model,
-				       combo->priv->source->shown_n_cols, 
-				       combo->priv->source->shown_cols_index);
+				       gda_set_source_get_data_model (s),
+				       gdaui_set_source_get_shown_n_cols (combo->priv->source), 
+				       gdaui_set_source_get_shown_columns (combo->priv->source));
 		_gdaui_combo_set_selected_ext (GDAUI_COMBO (combo->priv->combo_entry), values, NULL);
 		g_slist_free (values);
 		gdaui_combo_add_null (GDAUI_COMBO (combo->priv->combo_entry), combo->priv->null_possible);
@@ -287,36 +290,42 @@ void _gdaui_entry_combo_construct (GdauiEntryCombo* combo, GdauiSet *paramlist,
 	 * and use the values provided by the parameters to display the correct row */
 	null_possible = TRUE;
 	values = NULL;
-	for (list = source->source->nodes; list; list = list->next) {
+	for (list = gda_set_source_get_nodes (gdaui_set_source_get_source (source)); list; list = list->next) {
 		ComboNode *cnode = g_new0 (ComboNode, 1);
 		
 		cnode->node = GDA_SET_NODE (list->data);
-		cnode->value = gda_holder_get_value (cnode->node->holder);
+		cnode->value = NULL;
 		combo->priv->combo_nodes = g_slist_append (combo->priv->combo_nodes, cnode);
 
-		values = g_slist_append (values, (GValue *) cnode->value);
-		if (gda_holder_get_not_null (cnode->node->holder))
+		values = g_slist_append (values, (GValue *) gda_holder_get_value (gda_set_node_get_holder (cnode->node)));
+		if (gda_holder_get_not_null (gda_set_node_get_holder (cnode->node)))
 			null_possible = FALSE;
 	}
 	combo->priv->null_possible = null_possible;
 
 	/* create the combo box itself */
-	entry = gdaui_combo_new_with_model (GDA_DATA_MODEL (source->source->data_model), 
-					    combo->priv->source->shown_n_cols, 
-					    combo->priv->source->shown_cols_index);
+	entry = gdaui_combo_new_with_model (gda_set_source_get_data_model (gdaui_set_source_get_source (source)), 
+					    gdaui_set_source_get_shown_n_cols (combo->priv->source), 
+					    gdaui_set_source_get_shown_columns (combo->priv->source));
 	g_object_set (G_OBJECT (entry), "as-list", TRUE, NULL);
-	g_signal_connect (G_OBJECT (entry), "changed",
-			  G_CALLBACK (combo_contents_changed_cb), combo);
 
 	gdaui_entry_shell_pack_entry (GDAUI_ENTRY_SHELL (combo), entry);
 	gtk_widget_show (entry);
 	combo->priv->combo_entry = entry;
 
-	_gdaui_combo_set_selected_ext (GDAUI_COMBO (entry), values, NULL);
-	g_slist_free (values);
+	if (values) {
+		_gdaui_combo_set_selected_ext (GDAUI_COMBO (entry), values, NULL);
+		gdaui_entry_combo_set_reference_values (combo, values);
+		g_slist_free (values);
+	}
+
 	gdaui_combo_add_null (GDAUI_COMBO (entry), combo->priv->null_possible);
 
 	combo->priv->data_valid = combo->priv->null_possible ? TRUE : FALSE;
+
+	combo_contents_changed_cb ((GdauiCombo*) entry, combo);
+	g_signal_connect (G_OBJECT (entry), "changed",
+			  G_CALLBACK (combo_contents_changed_cb), combo);
 }
 
 static void
@@ -352,12 +361,9 @@ gdaui_entry_combo_dispose (GObject *object)
 			for (list = combo->priv->combo_nodes; list; list = list->next) {
 				ComboNode *node = COMBO_NODE (list->data);
 
-				if (node->value)
-					node->value = NULL; /* don't free that value since we have not copied it */
-				if (node->value_orig)
-					gda_value_free (node->value_orig);
-				if (node->value_default)
-					gda_value_free (node->value_default);
+				gda_value_free (node->value);
+				gda_value_free (node->value_orig);
+				gda_value_free (node->value_default);
 				g_free (node);
 			}
 			g_slist_free (combo->priv->combo_nodes);
@@ -441,9 +447,12 @@ combo_contents_changed_cb (G_GNUC_UNUSED GdauiCombo *entry, GdauiEntryCombo *com
 		for (list = combo->priv->combo_nodes; list; list = list->next) {
 			ComboNode *node = COMBO_NODE (list->data);
 
-			gtk_tree_model_get (model, &iter, node->node->source_column, &(node->value), -1);
-			/*g_print ("%s(): Set Combo Node value to %s\n", __FUNCTION__,
-			  node->value ? gda_value_stringify (node->value) : "Null");*/
+			gda_value_free (node->value);
+			gtk_tree_model_get (model, &iter, gda_set_node_get_source_column (node->node), &(node->value), -1);
+			if (node->value)
+				node->value = gda_value_copy (node->value);
+			/*g_print ("%s (%p): Set Combo Node value to %s (%p)\n", __FUNCTION__, combo, 
+			  node->value ? gda_value_stringify (node->value) : "Null", node->value);*/
 		}
 		
 		g_signal_emit_by_name (G_OBJECT (combo), "status-changed");
@@ -497,7 +506,7 @@ gdaui_entry_combo_set_values (GdauiEntryCombo *combo, GSList *values)
 		
 		model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo->priv->combo_entry));
 		if (gdaui_data_store_get_iter_from_values (GDAUI_DATA_STORE (model), &iter, 
-							   values, combo->priv->source->ref_cols_index)) {
+							   values, gdaui_set_source_get_ref_columns (combo->priv->source))) {
 			ComboNode *node;
 
 			real_combo_block_signals (combo);
@@ -507,8 +516,11 @@ gdaui_entry_combo_set_values (GdauiEntryCombo *combo, GSList *values)
 			/* adjusting the values */
 			for (list = combo->priv->combo_nodes; list; list = list->next) {
 				node = COMBO_NODE (list->data);
-				gtk_tree_model_get (model, &iter, node->node->source_column,
+				gda_value_free (node->value);
+				gtk_tree_model_get (model, &iter, gda_set_node_get_source_column (node->node),
 						    &(node->value), -1);
+				if (node->value)
+					node->value = gda_value_copy (node->value);
 			}
 			
 			combo->priv->null_forced = FALSE;
@@ -520,8 +532,10 @@ gdaui_entry_combo_set_values (GdauiEntryCombo *combo, GSList *values)
 	}
 	else  { /* set to NULL */
 		GSList *list;
-		for (list = combo->priv->combo_nodes; list; list = list->next)
+		for (list = combo->priv->combo_nodes; list; list = list->next) {
+			gda_value_free (COMBO_NODE (list->data)->value);
 			COMBO_NODE (list->data)->value = NULL;
+		}
 
 		if (combo->priv->null_possible) {
 			real_combo_block_signals (combo);
@@ -633,8 +647,9 @@ gdaui_entry_combo_set_reference_values (GdauiEntryCombo *combo, GSList *values)
 			GdaColumn *attrs;
 			GType type = GDA_TYPE_NULL;
 			
-			attrs = gda_data_model_describe_column (combo->priv->source->source->data_model, 
-								COMBO_NODE (nodes->data)->node->source_column);
+			attrs = gda_data_model_describe_column (
+			                    gda_set_source_get_data_model (gdaui_set_source_get_source (combo->priv->source)),
+								gda_set_node_get_source_column (COMBO_NODE (nodes->data)->node));
 			arg_value = (GValue*) (argptr->data);
 			
 			if (arg_value)
@@ -1018,19 +1033,6 @@ gdaui_entry_combo_get_attributes (GdauiDataEntry *iface)
 	return retval;
 }
 
-
-static gboolean
-gdaui_entry_combo_can_expand (GdauiDataEntry *iface, G_GNUC_UNUSED gboolean horiz)
-{
-	GdauiEntryCombo *combo;
-
-	g_return_val_if_fail (iface && GDAUI_IS_ENTRY_COMBO (iface), FALSE);
-	combo = GDAUI_ENTRY_COMBO (iface);
-	g_return_val_if_fail (combo->priv, FALSE);
-
-	return FALSE;
-}
-
 static void
 gdaui_entry_combo_grab_focus (GdauiDataEntry *iface)
 {
