@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -69,7 +70,6 @@ struct  _GdauiEntryShellPriv {
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
-static GtkCssProvider *css_provider = NULL;
 
 /**
  * gdaui_entry_shell_get_type:
@@ -142,21 +142,6 @@ gdaui_entry_shell_init (GdauiEntryShell *shell)
 	GtkWidget *button, *hbox, *arrow;
 	GValue *gval;
 
-	if (!css_provider) {
-		css_provider = gtk_css_provider_new ();
-                gtk_css_provider_load_from_data (css_provider,
-						 "* {\n"
-						 "-GtkArrow-arrow-scaling: 0.4;\n"
-						 "margin: 0;\n"
-						 "padding: 0;\n"
-						 "border-style: none;\n"
-						 "border-width: 0;\n"
-						 "-GtkButton-default-border: 0;\n"
-						 "-GtkButton-default-outside-border: 0;\n"
-						 "-GtkButton-inner-border: 0}",
-						 -1, NULL);
-	}
-
 	/* Private structure */
 	shell->priv = g_new0 (GdauiEntryShellPriv, 1);
 	shell->priv->embedder = NULL;
@@ -174,40 +159,21 @@ gdaui_entry_shell_init (GdauiEntryShell *shell)
 	/* Setting the initial layout */
 	gtk_viewport_set_shadow_type (GTK_VIEWPORT (shell), GTK_SHADOW_NONE);
 	gtk_container_set_border_width (GTK_CONTAINER (shell), 0);
-	gtk_style_context_add_provider (gtk_widget_get_style_context ((GtkWidget*) shell),
-					GTK_STYLE_PROVIDER (css_provider),
-					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
 	/* hbox */
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_container_add (GTK_CONTAINER (shell), hbox);
 	gtk_widget_show (hbox);
 	shell->priv->hbox = hbox;
-	gtk_style_context_add_provider (gtk_widget_get_style_context (hbox),
-					GTK_STYLE_PROVIDER (css_provider),
-					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
 	/* vbox to insert the real widget to edit data */
 	shell->priv->embedder = widget_embedder_new ();
-	gtk_style_context_add_provider (gtk_widget_get_style_context (shell->priv->embedder),
-					GTK_STYLE_PROVIDER (css_provider),
-					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	gtk_box_pack_start (GTK_BOX (hbox), shell->priv->embedder, TRUE, TRUE, 0);
-	gtk_widget_show (shell->priv->embedder);	
-
-
+	gtk_widget_show (shell->priv->embedder);
 
 	/* button to change the entry's state and to display that state */
-	arrow = gtk_arrow_new (GTK_ARROW_RIGHT, GTK_SHADOW_NONE);
-	gtk_style_context_add_provider (gtk_widget_get_style_context (arrow),
-					GTK_STYLE_PROVIDER (css_provider),
-					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-
+	arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_NONE);
 	button = gtk_button_new ();
-	gtk_style_context_add_provider (gtk_widget_get_style_context (button),
-					GTK_STYLE_PROVIDER (css_provider),
-					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-
 	gtk_container_add (GTK_CONTAINER (button), arrow);
 	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
 	shell->priv->button = button;
