@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -276,20 +276,22 @@ gdaui_numeric_entry_set_property (GObject *object,
                         entry->priv->nb_decimals = g_value_get_uint (value);
                         break;
                 case PROP_DECIMAL_SEP: {
-                        gchar sep = g_value_get_char (value);
+			gchar sep;
+                        sep = (gchar) g_value_get_schar (value);
                         if ((sep == 0) || (sep == '+') || (sep == '-'))
                                 g_warning (_("Decimal separator cannot be the '%c' character"), sep ? sep : '0');
                         else {
-                                entry->priv->decimal_sep = g_value_get_char (value);
+                                entry->priv->decimal_sep = (gchar) g_value_get_schar (value);
                         }
                         break;
                 }
                 case PROP_THOUSANDS_SEP: {
-                        gchar sep = g_value_get_char (value);
+			gchar sep;
+                        sep = (gchar) g_value_get_schar (value);
                         if ((sep == '+') || (sep == '-') || (sep == '_'))
                                 g_warning (_("Decimal thousands cannot be the '%c' character"), sep);
                         else {
-                                entry->priv->thousands_sep = g_value_get_char (value);
+                                entry->priv->thousands_sep = (gchar) g_value_get_schar (value);
                         }
                         break;
                 }
@@ -320,10 +322,10 @@ gdaui_numeric_entry_get_property (GObject *object,
                         g_value_set_uint (value, entry->priv->nb_decimals);
                         break;
                 case PROP_DECIMAL_SEP:
-                        g_value_set_char (value, entry->priv->decimal_sep);
+                        g_value_set_schar (value, (gint8) entry->priv->decimal_sep);
                         break;
                 case PROP_THOUSANDS_SEP:
-                        g_value_set_char (value, entry->priv->thousands_sep);
+                        g_value_set_schar (value, (gint8) entry->priv->thousands_sep);
                         break;
                 default:
                         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -351,14 +353,14 @@ text_unformat (GdauiNumericEntry *entry, gchar *str, gint *pos)
 	     *ptr;
 	     i++) {
 		if (*ptr == entry->priv->thousands_sep) {
-			g_memmove (ptr, ptr+1, len - (ptr - str));
+			memmove (ptr, ptr+1, len - (ptr - str));
 			len--;
 			if (*pos >= i)
 				*pos = *pos - 1;
 		}
 		else if ((*ptr == entry->priv->decimal_sep) &&
 			 (ptr[1] == entry->priv->decimal_sep)) {
-			g_memmove (ptr, ptr+1, len - (ptr - str));
+			memmove (ptr, ptr+1, len - (ptr - str));
 			len--;
 			/*if (*pos > i)
 			 *pos = *pos - 1;*/
@@ -703,7 +705,7 @@ gdaui_numeric_entry_get_value (GdauiNumericEntry *entry)
 		len = strlen (text);
 		for (ptr = text; *ptr; ) {
 			if (*ptr == entry->priv->thousands_sep)
-				g_memmove (ptr, ptr+1, len - (ptr - text));
+				memmove (ptr, ptr+1, len - (ptr - text));
 			else {
 				if (*ptr == entry->priv->decimal_sep)
 					*ptr = '.';
