@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -638,7 +639,7 @@ common_pict_add_cached_pixbuf (PictOptions *options, const GValue *value, GdkPix
 	else if (GDA_VALUE_HOLDS_BINARY (value)) {
 		const GdaBinary *bin;
 		bin = gda_value_get_binary (value);
-		hash = g_new (guint, 1);
+		hash = g_new (gint, 1);
 		*hash = compute_hash (bin->data, bin->binary_length);
 		g_hash_table_insert (options->pixbuf_hash, hash, g_object_ref (pixbuf));
 	}
@@ -650,7 +651,7 @@ common_pict_add_cached_pixbuf (PictOptions *options, const GValue *value, GdkPix
 		if (bin) {
 			if (!bin->data && blob->op)
 				gda_blob_op_read_all (blob->op, (GdaBlob*) blob);
-			hash = g_new (guint, 1);
+			hash = g_new (gint, 1);
 			*hash = compute_hash (bin->data, bin->binary_length);
 			g_hash_table_insert (options->pixbuf_hash, hash, g_object_ref (pixbuf));
 		}
