@@ -51,7 +51,7 @@ GtkWidget *
 do_ddl_queries (GtkWidget *do_widget)
 {  
 	if (!window) {
-		GtkWidget *table;
+		GtkWidget *grid;
 		GtkWidget *label;
 		GtkWidget *wid;
 		DemoData *data;
@@ -73,25 +73,25 @@ do_ddl_queries (GtkWidget *do_widget)
 		g_signal_connect (window, "destroy",
 				  G_CALLBACK (gtk_widget_destroyed), &window);
 		
-		table = gtk_table_new (3, 2, FALSE);
+		grid = gtk_grid_new ();
 		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (window))),
-				    table, TRUE, TRUE, 0);
-		gtk_container_set_border_width (GTK_CONTAINER (table), 5);
+				    grid, TRUE, TRUE, 0);
+		gtk_container_set_border_width (GTK_CONTAINER (grid), 5);
 		
 		label = gtk_label_new ("<b>Tested provider and operation:</b>");
 		gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 		gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
-		gtk_table_attach (GTK_TABLE (table), label, 0, 2, 0, 1, GTK_FILL, 0, 0, 0);
+		gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 2, 1);
 		
 		/* provider selection */
 		label = gtk_label_new ("Tested provider:");
 		gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
-		gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
+		gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
 
 		wid = gdaui_provider_selector_new ();
 		gdaui_provider_selector_set_provider (GDAUI_PROVIDER_SELECTOR (wid),
 								  "SQLite");
-		gtk_table_attach (GTK_TABLE (table), wid, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+		gtk_grid_attach (GTK_GRID (grid), wid, 1, 1, 1, 1);
 		data->prov_sel = GDAUI_PROVIDER_SELECTOR (wid);
 		g_signal_connect (G_OBJECT (data->prov_sel), "changed", 
 				  G_CALLBACK (tested_provider_changed_cb), data);
@@ -99,10 +99,10 @@ do_ddl_queries (GtkWidget *do_widget)
 		/* operation selection */
 		label = gtk_label_new ("Tested operation:");
 		gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
-		gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3, GTK_FILL, 0, 0, 0);
+		gtk_grid_attach (GTK_GRID (grid), label, 0, 2, 1, 1);
 		
 		wid = gdaui_combo_new ();
-		gtk_table_attach (GTK_TABLE (table), wid, 1, 2, 2, 3, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+		gtk_grid_attach (GTK_GRID (grid), wid, 1, 2, 1, 1);
 		g_signal_connect (G_OBJECT (wid), "changed",
 				  G_CALLBACK (tested_operation_changed_cb), data);
 		data->op_combo = wid;
@@ -111,21 +111,22 @@ do_ddl_queries (GtkWidget *do_widget)
 		label = gtk_label_new ("<b>GdauiServerOperation widget:</b>");
 		gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
 		gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-		gtk_table_attach (GTK_TABLE (table), label, 0, 2, 3, 4, GTK_FILL, 0, 0, 5);
+		gtk_grid_attach (GTK_GRID (grid), label, 0, 3, 2, 1);
 
 		sw = gtk_scrolled_window_new (FALSE, 0);
 		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 						GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 		gtk_widget_set_size_request (sw, 600, 450);
-		gtk_table_attach_defaults (GTK_TABLE (table), sw, 0, 2, 4, 5);
+		gtk_grid_attach (GTK_GRID (grid), sw, 0, 4, 2, 1);
 		vp = gtk_viewport_new (NULL, NULL);
+		gtk_widget_set_name (vp, "gdaui-transparent-background");
 		gtk_viewport_set_shadow_type (GTK_VIEWPORT (vp), GTK_SHADOW_NONE);
 		gtk_container_add (GTK_CONTAINER (sw), vp);
 		data->op_container = vp;
 		
 		/* bottom buttons */
 		bbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
-		gtk_table_attach (GTK_TABLE (table), bbox, 0, 2, 5, 6, 0, 0, 0, 0);
+		gtk_grid_attach (GTK_GRID (grid), bbox, 0, 5, 2, 1);
 
 		wid = gtk_button_new_with_label ("Show named parameters");
 		data->show_button = wid;
@@ -349,9 +350,23 @@ extract_named_parameters (GdaServerOperation *op, const gchar *root_path, GtkTex
 		g_free (str);
 		break;
 	}
-	case GDA_SERVER_OPERATION_NODE_SEQUENCE:
+	case GDA_SERVER_OPERATION_NODE_SEQUENCE: {
 		gtk_text_buffer_insert (tbuffer, &iter, "Sequence)\n", -1);
+		guint i, size = gda_server_operation_get_sequence_size (op, root_path);
+		for (i = 0; i < size; i++) {
+			gchar **names;
+			names = gda_server_operation_get_sequence_item_names (op, root_path);
+			guint n;
+			for (n = 0; names [n]; n++) {
+				gchar *npath;
+				npath = g_strdup_printf ("%s/%u%s", root_path, i, names [n]);
+				extract_named_parameters (op, npath, tbuffer);
+				g_free (npath);
+			}
+			g_strfreev (names);
+		}
 		break;
+	}
 
 	case GDA_SERVER_OPERATION_NODE_SEQUENCE_ITEM:
 		gtk_text_buffer_insert (tbuffer, &iter, "Sequence item)\n", -1);
@@ -428,6 +443,22 @@ show_named_parameters (G_GNUC_UNUSED GtkButton *button, DemoData *data)
                                     "weight", PANGO_WEIGHT_BOLD,
                                     "foreground", "blue", NULL);
 
+	xmlNodePtr xml;
+	xml = gda_server_operation_save_data_to_xml (data->op, NULL);
+	if (xml) {
+		g_print ("XML rendering of the GdaServerOperation is:\n");
+                xmlBufferPtr buffer;
+                buffer = xmlBufferCreate ();
+                xmlNodeDump (buffer, NULL, xml, 0, 1);
+                xmlFreeNode (xml);
+                xmlBufferDump (stdout, buffer);
+                xmlBufferFree (buffer);
+		g_print ("\n");
+	}
+	else {
+		g_print ("XML rendering ERROR\n");
+	}
+
 	root_nodes = gda_server_operation_get_root_nodes (data->op);
 	for (i = 0; root_nodes && root_nodes[i]; i++)
 		extract_named_parameters (data->op, root_nodes[i], buffer);
@@ -475,9 +506,9 @@ show_sql (G_GNUC_UNUSED GtkButton *button, DemoData *data)
 		else
 			msg = g_strdup_printf ("<b>SQL:</b>\n%s", sql);
 
-		dlg = gtk_message_dialog_new_with_markup (GTK_WINDOW (data->top_window),
-							  GTK_DIALOG_MODAL,
-							  msg_type, GTK_BUTTONS_CLOSE, msg);
+		dlg = gtk_message_dialog_new (GTK_WINDOW (data->top_window),
+					      GTK_DIALOG_MODAL, msg_type, GTK_BUTTONS_CLOSE, NULL);
+		gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dlg), msg);
 		g_free (sql);
 		g_free (msg);
 
