@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -76,7 +77,6 @@ struct _GdauiDataProxyInfoPriv
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
-static GtkCssProvider *css_provider = NULL;
 
 /* properties */
 enum {
@@ -466,15 +466,6 @@ modif_buttons_make (GdauiDataProxyInfo *info)
 	GtkWidget *wid;
 	GdauiDataProxyInfoFlag flags = info->priv->flags;
 
-	if (!css_provider) {
-		css_provider = gtk_css_provider_new ();
-		gtk_css_provider_load_from_data (css_provider,
-						 "* {\n"
-						 "-GtkToolbar-shadow-type : none;\n"
-						 "-GtkSpinButton-shadow-type : none}",
-						 -1, NULL);
-        }
-
 	if (! info->priv->data_proxy)
 		return;
 
@@ -485,8 +476,6 @@ modif_buttons_make (GdauiDataProxyInfo *info)
 		gtk_widget_unparent (info->priv->tool_item);
 	}
 
-	gboolean ensure_update = FALSE;
-
 	if (info->priv->uimanager) {
 		if (info->priv->merge_id_row_modif) {
 			gtk_ui_manager_remove_ui (info->priv->uimanager, info->priv->merge_id_row_modif);
@@ -553,9 +542,6 @@ modif_buttons_make (GdauiDataProxyInfo *info)
 	g_object_ref_sink (info->priv->buttons_bar);
 	gtk_toolbar_set_icon_size (GTK_TOOLBAR (info->priv->buttons_bar), GTK_ICON_SIZE_MENU);
 	g_object_set (G_OBJECT (info->priv->buttons_bar), "toolbar-style", GTK_TOOLBAR_ICONS, NULL);
-	gtk_style_context_add_provider (gtk_widget_get_style_context (info->priv->buttons_bar),
-					GTK_STYLE_PROVIDER (css_provider),
-					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	gtk_box_pack_start (GTK_BOX (info), info->priv->buttons_bar, TRUE, TRUE, 0);
 	gtk_widget_show (info->priv->buttons_bar);
 
@@ -591,9 +577,6 @@ modif_buttons_make (GdauiDataProxyInfo *info)
 			wid = gtk_spin_button_new_with_range (0, 1, 1);
 
 			gtk_widget_override_font (wid, fdc);
-			gtk_style_context_add_provider (gtk_widget_get_style_context (wid),
-							GTK_STYLE_PROVIDER (css_provider),
-							GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 			gtk_spin_button_set_digits (GTK_SPIN_BUTTON (wid), 0);
 			gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (wid), TRUE);
 			gtk_box_pack_start (GTK_BOX (toolwid), wid, FALSE, TRUE, 2);
@@ -628,13 +611,16 @@ modif_buttons_make (GdauiDataProxyInfo *info)
 static void
 row_spin_changed_cb (GtkSpinButton *spin, GdauiDataProxyInfo *info)
 {
-	gint row;
+	gint row, nrows;
 	gint value = gtk_spin_button_get_value (spin);
+	nrows = gda_data_model_get_n_rows (GDA_DATA_MODEL (info->priv->proxy));
 
-	if ((value >= 1) &&
-	    (value <= gda_data_model_get_n_rows (GDA_DATA_MODEL (info->priv->proxy))))
+	if ((value >= 1) && (value <= nrows))
 		row = value - 1;
-
+	else if (value > nrows)
+		row = nrows - 1;
+	else
+		row = 0;
 	gda_data_model_iter_move_to_row (gdaui_data_selector_get_data_set (GDAUI_DATA_SELECTOR (info->priv->data_proxy)),
 					 row);
 }
@@ -659,7 +645,6 @@ idle_modif_buttons_update (GdauiDataProxyInfo *info)
 {
 	GdaDataModelIter *model_iter;
 	gboolean wrows, filtered_proxy = FALSE;
-	gint has_selection;
 	gint row;
 
 	gint proxy_rows = 0;
@@ -762,11 +747,12 @@ idle_modif_buttons_update (GdauiDataProxyInfo *info)
 		gboolean is_inserted = FALSE;
 		gboolean force_del_btn = FALSE;
 		gboolean force_undel_btn = FALSE;
+		gboolean has_selection;
 
+		has_selection = (row >= 0) ? TRUE : FALSE;
 		if (info->priv->proxy) {
 			changed = gda_data_proxy_has_changed (info->priv->proxy);
 
-			has_selection = (row >= 0) ? TRUE : FALSE;
 			if (has_selection) {
 				to_be_deleted = gda_data_proxy_row_is_deleted (info->priv->proxy, row);
 				is_inserted = gda_data_proxy_row_is_inserted (info->priv->proxy, row);
