@@ -110,7 +110,7 @@ static const GValue        *gda_data_meta_wrapper_get_value_at    (GdaDataModel
 static GObjectClass *parent_class = NULL;
 
 /**
- * gda_data_meta_wrapper_get_type
+ * gda_data_meta_wrapper_get_type:
  *
  * Returns: the #GType of GdaDataMetaWrapper.
  */
@@ -120,7 +120,7 @@ _gda_data_meta_wrapper_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaDataMetaWrapperClass),
 			(GBaseInitFunc) NULL,
@@ -140,12 +140,12 @@ _gda_data_meta_wrapper_get_type (void)
 			NULL
 		};
 
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0) {
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaDataMetaWrapper", &info, 0);
 			g_type_add_interface_static (type, GDA_TYPE_DATA_MODEL, &data_model_info);
 		}
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -328,7 +328,7 @@ gda_data_meta_wrapper_get_property (GObject *object,
 }
 
 /**
- * gda_data_meta_wrapper_new
+ * gda_data_meta_wrapper_new:
  * @model: a #GdaDataModel
  *
  * Creates a new #GdaDataModel object which buffers the rows of @model. This object is useful
@@ -468,7 +468,7 @@ to_lower (gchar *str)
 }
 
 /**
- * _gda_data_meta_wrapper_compute_value
+ * _gda_data_meta_wrapper_compute_value:
  *
  * Returns:
  *  - NULL if no changes are necessary from the current value
