@@ -2,7 +2,7 @@
  * Copyright (C) 2001 Cleber Rodrigues <cleberrrjr@bol.com.br>
  * Copyright (C) 2001 - 2002 Rodrigo Moya <rodrigo@gnome-db.org>
  * Copyright (C) 2002 Gonzalo Paniagua Javier <gonzalo@src.gnome.org>
- * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2005 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -73,6 +73,8 @@ GdaDataModel      *gda_data_model_array_new_with_g_types  (gint cols, ...);
 GdaDataModel      *gda_data_model_array_new_with_g_types_v (gint cols, GType *types);
 GdaDataModel      *gda_data_model_array_new               (gint cols);
 GdaDataModelArray *gda_data_model_array_copy_model        (GdaDataModel *src, GError **error);
+GdaDataModelArray *gda_data_model_array_copy_model_ext    (GdaDataModel *src,
+							   gint ncols, gint *cols, GError **error);
 
 GdaRow            *gda_data_model_array_get_row           (GdaDataModelArray *model, gint row, GError **error);
 void               gda_data_model_array_set_n_columns     (GdaDataModelArray *model, gint cols);
