@@ -26,6 +26,7 @@
 #include <db.h>
 #include <gmodule.h>
 #include <libgda/gda-server-provider.h>
+#include <libgda/gda-debug-macros.h>
 
 #define BDB_VERSION  (10000*DB_VERSION_MAJOR+100*DB_VERSION_MINOR+DB_VERSION_PATCH)
 
@@ -229,7 +230,7 @@ gda_data_model_bdb_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaDataModelBdbClass),
 			(GBaseInitFunc) NULL,
@@ -248,7 +249,7 @@ gda_data_model_bdb_get_type (void)
                         NULL
                 };
 
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0) {
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaDataModelBdb", &info, 0);
 			g_type_add_interface_static (type, GDA_TYPE_DATA_MODEL, &data_model_info);
@@ -279,7 +280,7 @@ gda_data_model_bdb_get_type (void)
 			else
 				g_module_make_resident (module);
 		}
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -491,7 +492,7 @@ gda_data_model_bdb_new (const gchar *filename, const gchar *db_name)
  *
  * Get the list of errors which have occurred while using @model
  *
- * Returns: (element-type GObject.Error) (transfer none): a read-only list of #GError pointers, or %NULL if no error has occurred
+ * Returns: (element-type GError) (transfer none): a read-only list of #GError pointers, or %NULL if no error has occurred
  */
 const GSList *
 gda_data_model_bdb_get_errors (GdaDataModelBdb *model)
