@@ -1,9 +1,10 @@
 /*
  * Copyright (C) 2008 - 2010 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
+ * Copyright (C) 2012 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,6 +30,7 @@
 #include <sql-parser/gda-sql-statement.h>
 #include <sql-parser/gda-statement-struct-util.h>
 #include <libgda/gda-attributes-manager.h>
+#include <libgda/gda-debug-macros.h>
 
 /*
  * Main static functions
@@ -93,7 +95,7 @@ gda_meta_struct_get_type (void) {
 	static GType type = 0;
 	
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaMetaStructClass),
 			(GBaseInitFunc) NULL,
@@ -107,10 +109,10 @@ gda_meta_struct_get_type (void) {
 			0
 		};
 		
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaMetaStruct", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -1120,10 +1122,13 @@ _meta_struct_complement (GdaMetaStruct *mstruct, GdaMetaDbObjectType type,
 			
 			nrows = gda_data_model_get_n_rows (model);
 			for (i = 0; i < nrows; i++) {
-				GdaMetaTableForeignKey *tfk;
+				GdaMetaTableForeignKey *tfk = NULL;
 				const GValue *fk_catalog, *fk_schema, *fk_tname, *fk_name;
 				const GValue *upd_policy, *del_policy;
 
+				GdaDataModel *fk_cols = NULL;
+				GdaDataModel *ref_pk_cols = NULL;
+
 				fk_catalog = gda_data_model_get_value_at (model, 0, i, error);
 				if (!fk_catalog) goto onfkerror;
 				fk_schema = gda_data_model_get_value_at (model, 1, i, error);
@@ -1175,7 +1180,6 @@ _meta_struct_complement (GdaMetaStruct *mstruct, GdaMetaDbObjectType type,
 				/* FIXME: compute @cols_nb, and all the @*_array members (ref_pk_cols_array must be
 				 * initialized with -1 values everywhere */
 				sql = "SELECT k.column_name, c.ordinal_position FROM _key_column_usage k INNER JOIN _columns c ON (c.table_catalog = k.table_catalog AND c.table_schema = k.table_schema AND c.table_name=k.table_name AND c.column_name=k.column_name) WHERE k.table_catalog = ##tc::string AND k.table_schema = ##ts::string AND k.table_name = ##tname::string AND k.constraint_name = ##cname::string ORDER BY k.ordinal_position";
-				GdaDataModel *fk_cols, *ref_pk_cols;
 				gboolean fkerror = FALSE;
 				cvalue = gda_data_model_get_value_at (model, 3, i, error);
 				if (!cvalue) goto onfkerror;
@@ -1267,8 +1271,8 @@ _meta_struct_complement (GdaMetaStruct *mstruct, GdaMetaDbObjectType type,
 					g_object_unref (fk_cols);
 				if (ref_pk_cols)
 					g_object_unref (ref_pk_cols);
-				
-				mt->fk_list = g_slist_prepend (mt->fk_list, tfk);
+				if (tfk)
+					mt->fk_list = g_slist_prepend (mt->fk_list, tfk);
 				goto onerror;
 			}
 			mt->fk_list = g_slist_reverse (mt->fk_list);
@@ -2545,7 +2549,7 @@ copyerror:
 }
 
 /**
- * gda_meta_struct_add_db_object:
+ * _gda_meta_struct_add_db_object:
  * @mstruct: a #GdaMetaStruct object
  * @dbo: a #GdaMetaDbObject structure
  * @error: (allow-none): a place to store errors, or %NULL
@@ -2558,7 +2562,7 @@ copyerror:
  * Returns: (transfer none): a pointer to the #GdaMetaDbObject used in @mstruct to represent the added database object (may be @dbo or not)
  */
 GdaMetaDbObject *
-gda_meta_struct_add_db_object (GdaMetaStruct *mstruct, GdaMetaDbObject *dbo, GError **error)
+_gda_meta_struct_add_db_object (GdaMetaStruct *mstruct, GdaMetaDbObject *dbo, GError **error)
 {
 	GdaMetaDbObject *edbo;
 	GValue *v1 = NULL, *v2 = NULL, *v3 = NULL;
