@@ -1,8 +1,9 @@
 /*
  * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2013 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2013 Daniel Espinosa <esodan@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -43,6 +44,587 @@
 extern xmlDtdPtr gda_paramlist_dtd;
 extern gchar *gda_lang_locale;
 
+#ifdef GSEAL_ENABLE
+/**
+ * GdaSetGroup:
+ * @nodes: (element-type Gda.SetNode): list of GdaSetNode, at least one entry
+ * @nodes_source: (allow-none):  if NULL, then @nodes contains exactly one entry 
+ *
+ * Since 5.2, you must consider this struct as opaque. Any access to its internal must use public API.
+ * Don't try to use #gda_set_group_free on a struct that was created manually.
+ */
+struct _GdaSetGroup {
+	GSList       *nodes;       /* list of GdaSetNode, at least one entry */
+	GdaSetSource *nodes_source; /* if NULL, then @nodes contains exactly one entry */
+
+	/*< private >*/
+	/* Padding for future expansion */
+	gpointer      _gda_reserved1;
+	gpointer      _gda_reserved2;
+};
+#else
+#endif
+/*
+   Register GdaSetGroup type
+*/
+GType
+gda_set_group_get_type (void)
+{
+	static GType type = 0;
+
+	if (G_UNLIKELY (type == 0)) {
+        if (type == 0)
+			type = g_boxed_type_register_static ("GdaSetGroup",
+							     (GBoxedCopyFunc) gda_set_group_copy,
+							     (GBoxedFreeFunc) gda_set_group_free);
+	}
+
+	return type;
+}
+
+/**
+ * gda_set_group_new:
+ * @node: a #GdaSetNode struct
+ * 
+ * Creates a new #GdaSetGroup struct. If @source is %NULL then new group contains 
+ * just one #GdaSetNode.
+ *
+ * Return: (transfer full): a new #GdaSetGroup struct.
+ *
+ * Since: 5.2
+ */
+GdaSetGroup*
+gda_set_group_new (GdaSetNode *node)
+{
+	GdaSetGroup *sg;
+	
+	g_return_val_if_fail (node, NULL);
+
+	sg = g_new0 (GdaSetGroup, 1);
+	sg->nodes_source = NULL;
+	sg->nodes = NULL;
+	sg->nodes = g_slist_append (sg->nodes, node);
+	return sg;
+}
+
+/**
+ * gda_set_group_copy:
+ * @sg: a #GdaSetGroup
+ *
+ * Copy constructor.
+ *
+ * Returns: a new #GdaSetGroup
+ *
+ * Since: 5.2
+ */
+GdaSetGroup *
+gda_set_group_copy (GdaSetGroup *sg)
+{
+	g_return_val_if_fail (sg, NULL);
+
+	GdaSetGroup *n;
+	n = g_new0 (GdaSetGroup, 1);
+	n->nodes_source = sg->nodes_source;
+	n->nodes = g_slist_copy (sg->nodes);
+	return n;
+}
+
+/**
+ * gda_set_group_free:
+ * @sg: (allow-none): a #GdaSetGroup struct to free
+ * 
+ * Frees any resources taken by @sg struct. If @sg is %NULL, then nothing happens.
+ *
+ * Since: 5.2
+ */
+void
+gda_set_group_free (GdaSetGroup *sg)
+{
+	g_return_if_fail(sg);
+	g_slist_free (sg->nodes);
+	g_free (sg);
+}
+
+/**
+ * gda_set_group_set_source:
+ * @sg: a #GdaSetGroup
+ * @source: a #GdaSetSource to set
+ * 
+ * Since: 5.2
+ */
+void 
+gda_set_group_set_source (GdaSetGroup *sg, GdaSetSource *source)
+{
+	g_return_if_fail (sg);
+	sg->nodes_source = source;
+}
+
+/**
+ * gda_set_group_get_source:
+ * @sg: a #GdaSetGroup
+ * 
+ * Returns: a #GdaSetSource. If %NULL then @sg contains just one element.
+ * 
+ * Since: 5.2
+ */
+GdaSetSource*
+gda_set_group_get_source      (GdaSetGroup *sg)
+{
+	g_return_val_if_fail (sg, NULL);
+	return sg->nodes_source;
+}
+
+/**
+ * gda_set_group_add_node:
+ * @sg: a #GdaSetGroup
+ * @node: a #GdaSetNode to set
+ * 
+ * Since: 5.2
+ */
+void 
+gda_set_group_add_node (GdaSetGroup *sg, GdaSetNode *node)
+{
+	g_return_if_fail (sg);
+	g_return_if_fail (node);
+	sg->nodes = g_slist_append (sg->nodes, node);
+}
+
+/**
+ * gda_set_group_get_node:
+ * @sg: a #GdaSetGroup
+ * 
+ * This method always return first #GdaSetNode in @sg.
+ * 
+ * Returns: first #GdaSetNode in @sg.
+ * 
+ * Since: 5.2
+ */
+GdaSetNode* 
+gda_set_group_get_node (GdaSetGroup *sg)
+{
+	g_return_val_if_fail (sg, NULL);
+	g_return_val_if_fail (sg->nodes, NULL);
+	return GDA_SET_NODE (sg->nodes->data);
+}
+
+/**
+ * gda_set_group_get_nodes:
+ * @sg: a #GdaSetGroup
+ * 
+ * Returns a #GSList with the #GdaSetNode grouped by @sg. You must use
+ * #g_slist_free on returned list.
+ * 
+ * Returns: (transfer none) (element-type Gda.SetNode): a #GSList with all nodes in @sg. 
+ * 
+ * Since: 5.2
+ */
+GSList* 
+gda_set_group_get_nodes (GdaSetGroup *sg)
+{
+	g_return_val_if_fail (sg, NULL);
+	g_return_val_if_fail (sg->nodes, NULL);
+	return sg->nodes;
+}
+
+/**
+ * gda_set_group_get_n_nodes:
+ * @sg: a #GdaSetGroup
+ * 
+ * Returns: number of nodes in @sg. 
+ * 
+ * Since: 5.2
+ */
+gint
+gda_set_group_get_n_nodes (GdaSetGroup *sg)
+{
+	g_return_val_if_fail (sg, -1);
+	return g_slist_length (sg->nodes);
+}
+
+#ifdef GSEAL_ENABLE
+/**
+ * GdaSetSource:
+ * @data_model: Can't be NULL
+ * @nodes: (element-type Gda.SetNode): list of #GdaSetNode for which source_model == @data_model
+ * 
+ * Since 5.2, you must consider this struct as opaque. Any access to its internal must use public API.
+ * Don't try to use #gda_set_source_free on a struct that was created manually.
+ **/
+struct _GdaSetSource {
+	GdaDataModel   *data_model;   /* Can't be NULL */
+	GSList         *nodes;        /* list of #GdaSetNode for which source_model == @data_model */
+
+	/*< private >*/
+	/* Padding for future expansion */
+	gpointer        _gda_reserved1;
+	gpointer        _gda_reserved2;
+	gpointer        _gda_reserved3;
+	gpointer        _gda_reserved4;
+};
+#else
+#endif
+
+/*
+   Register GdaSetSource type
+*/
+GType
+gda_set_source_get_type (void)
+{
+	static GType type = 0;
+
+	if (G_UNLIKELY (type == 0)) {
+        if (type == 0)
+			type = g_boxed_type_register_static ("GdaSetSource",
+							     (GBoxedCopyFunc) gda_set_source_copy,
+							     (GBoxedFreeFunc) gda_set_source_free);
+	}
+
+	return type;
+}
+
+/**
+ * gda_set_source_new:
+ * @model: a #GdaDataModel
+ * 
+ * Creates a new #GdaSetSource struct.
+ *
+ * Return: (transfer full): a new #GdaSetSource struct.
+ *
+ * Since: 5.2
+ */
+GdaSetSource*
+gda_set_source_new (GdaDataModel *model)
+{
+	g_return_val_if_fail (model != NULL && GDA_IS_DATA_MODEL (model), NULL);
+	GdaSetSource *s = g_new0 (GdaSetSource, 1);
+	s->nodes = NULL;
+	s->data_model = g_object_ref (model);
+
+	return s;
+}
+
+/**
+ * gda_set_source_copy:
+ * @s: a #GdaSetGroup
+ *
+ * Copy constructor.
+ *
+ * Returns: a new #GdaSetSource
+ *
+ * Since: 5.2
+ */
+GdaSetSource *
+gda_set_source_copy (GdaSetSource *s)
+{
+	GdaSetSource *n;
+	g_return_val_if_fail (s, NULL);	
+	n = gda_set_source_new (gda_set_source_get_data_model (s));
+	n->nodes = g_slist_copy (s->nodes);
+	return n;
+}
+	
+/**
+ * gda_set_source_free:
+ * @s: (allow-none): a #GdaSetSource struct to free
+ * 
+ * Frees any resources taken by @s struct. If @s is %NULL, then nothing happens.
+ *
+ * Since: 5.2
+ */
+void
+gda_set_source_free (GdaSetSource *s)
+{
+	g_return_if_fail(s);
+	g_object_unref (s->data_model);
+	g_slist_free (s->nodes); /* FIXME: A source must own its nodes, then they must be freed here
+										this leaves to others responsability free nodes BEFORE
+										to free this source */
+	g_free (s);
+}
+
+/**
+ * gda_set_source_get_data_model:
+ * @s: a #GdaSetSource
+ * 
+ * Returns: (transfer none): a #GdaDataModel used by @s
+ * 
+ * Since: 5.2
+ */
+GdaDataModel*
+gda_set_source_get_data_model (GdaSetSource *s)
+{
+	g_return_val_if_fail (s, NULL);
+	return s->data_model;
+}
+
+/**
+ * gda_set_source_set_data_model:
+ * @s: a #GdaSetSource struct to free
+ * @model: a #GdaDataModel
+ * 
+ * Set a #GdaDataModel
+ *
+ * Since: 5.2
+ */
+void
+gda_set_source_set_data_model (GdaSetSource *s, GdaDataModel *model)
+{
+	g_return_if_fail (s);
+	g_return_if_fail (GDA_IS_DATA_MODEL (model));
+	s->data_model = g_object_ref (model);
+}
+
+/**
+ * gda_set_source_add_node:
+ * @s: a #GdaSetSource
+ * @node: a #GdaSetNode to add
+ * 
+ * Set a #GdaDataModel
+ *
+ * Since: 5.2
+ */
+void
+gda_set_source_add_node (GdaSetSource *s, GdaSetNode *node)
+{
+	g_return_if_fail (s);
+	g_return_if_fail (node);
+	s->nodes = g_slist_append (s->nodes, node);
+}
+
+/**
+ * gda_set_source_get_nodes:
+ * @s: a #GdaSetSource
+ * 
+ * Returns: (transfer none) (element-type Gda.SetNode): a list of #GdaSetNode structs
+ *
+ * Since: 5.2
+ */
+GSList*
+gda_set_source_get_nodes (GdaSetSource *s)
+{
+	g_return_val_if_fail (s, NULL);
+	g_return_val_if_fail (s->nodes, NULL);
+	return s->nodes;
+}
+
+/**
+ * gda_set_source_get_n_nodes:
+ * @s: a #GdaSetSource
+ * 
+ * Returns: number of nodes in @sg. 
+ * 
+ * Since: 5.2
+ */
+gint
+gda_set_source_get_n_nodes (GdaSetSource *s)
+{
+	g_return_val_if_fail (s, -1);
+	return g_slist_length (s->nodes);
+}
+#ifdef GSEAL_ENABLE
+/**
+ * GdaSetNode:
+ * @holder: a #GdaHolder. It can't be NULL
+ * @source_model: a #GdaDataModel. It could be NULL
+ * @source_column: a #gint with the number of column in @source_model
+ * 
+ * Since 5.2, you must consider this struct as opaque. Any access to its internal must use public API.
+ * Don't try to use #gda_set_node_free on a struct that was created manually.
+ */
+struct _GdaSetNode {
+	GdaHolder    *holder;        /* Can't be NULL */
+	GdaDataModel *source_model;  /* may be NULL */
+	gint          source_column; /* unused if @source_model is NULL */
+
+	/*< private >*/
+	/* Padding for future expansion */
+	gpointer      _gda_reserved1;
+	gpointer      _gda_reserved2;
+};
+#endif
+/*
+   Register GdaSetNode type
+*/
+GType
+gda_set_node_get_type (void)
+{
+	static GType type = 0;
+
+	if (G_UNLIKELY (type == 0)) {
+        if (type == 0)
+			type = g_boxed_type_register_static ("GdaSetNode",
+							     (GBoxedCopyFunc) gda_set_node_copy,
+							     (GBoxedFreeFunc) gda_set_node_free);
+	}
+
+	return type;
+}
+
+/**
+ * gda_set_node_new:
+ * @holder: a #GdaHolder to used by new #GdaSetNode
+ * 
+ * Creates a new #GdaSetNode struct.
+ *
+ * Return: (transfer full): a new #GdaSetNode struct.
+ *
+ * Since: 5.2
+ */
+GdaSetNode*
+gda_set_node_new (GdaHolder *holder)
+{
+	g_return_val_if_fail (GDA_IS_HOLDER (holder), NULL);
+	GdaSetNode *n = g_new0 (GdaSetNode, 1);
+	n->holder = holder;
+	n->source_model = NULL;
+	return n;
+}
+
+/**
+ * gda_set_node_copy:
+ * @node: a #GdaSetNode to copy from
+ *
+ * Copy constructor.
+ *
+ * Returns: a new #GdaSetNode
+ *
+ * Since: 5.2
+ */
+GdaSetNode *
+gda_set_node_copy (GdaSetNode *node)
+{
+	g_return_val_if_fail (node, NULL);
+
+	GdaSetNode *n;
+	n = gda_set_node_new (gda_set_node_get_holder (node));
+	gda_set_node_set_source_column (n, gda_set_node_get_source_column (node));
+	gda_set_node_set_holder (n, gda_set_node_get_holder (node));
+	gda_set_node_set_data_model (n, gda_set_node_get_data_model (node));
+	return n;
+}
+
+/**
+ * gda_set_node_free:
+ * @node: (allow-none): a #GdaSetNode struct to free
+ * 
+ * Frees any resources taken by @node struct. If @node is %NULL, then nothing happens.
+ *
+ * Since: 5.2
+ */
+void
+gda_set_node_free (GdaSetNode *node)
+{
+	if (node == NULL)
+		return;
+	g_free (node);
+}
+
+/**
+ * gda_set_node_get_holder:
+ * @node: a #GdaSetNode struct to get holder from
+ * 
+ * Returns: (transfer none): the #GdaHolder used by @node
+ *
+ * Since: 5.2
+ */
+GdaHolder*
+gda_set_node_get_holder (GdaSetNode *node)
+{
+	g_return_val_if_fail (node, NULL);
+	return node->holder;
+}
+
+/**
+ * gda_set_node_set_holder:
+ * @node: a #GdaSetNode struct to set holder to
+ * 
+ * Set a #GdaHolder to @node.
+ *
+ * Since: 5.2
+ */
+void
+gda_set_node_set_holder (GdaSetNode *node, GdaHolder *holder)
+{
+	g_return_if_fail (node);
+	g_return_if_fail (GDA_IS_HOLDER (holder));
+	node->holder = holder;
+}
+
+/**
+ * gda_set_node_get_data_model:
+ * @node: a #GdaSetNode struct to get holder from
+ * 
+ * Returns: (transfer none): the #GdaDataModel used by @node
+ *
+ * Since: 5.2
+ */
+GdaDataModel*
+gda_set_node_get_data_model (GdaSetNode *node)
+{
+	g_return_val_if_fail (node, NULL);
+	return node->source_model;
+}
+
+/**
+ * gda_set_node_set_data_model:
+ * @node: a #GdaSetNode struct to set data model to
+ * @model: (allow-none): a #GdaDataModel to be used by @node
+ * 
+ * Set a #GdaDataModel to be used by @node. @model increment its reference
+ * counting when set. Internally referenced column number is set to first column
+ * in @model.
+ *
+ * Since: 5.2
+ */
+void
+gda_set_node_set_data_model (GdaSetNode *node, GdaDataModel *model)
+{
+	g_return_if_fail (node);
+	if (GDA_IS_DATA_MODEL (model)) {
+		node->source_model = model;
+		node->source_column = 0;
+	}
+	else {
+		node->source_model = NULL;
+		node->source_column = -1;
+	}
+}
+
+/**
+ * gda_set_node_get_source_column:
+ * @node: a #GdaSetNode struct to get column source from 
+ * 
+ * Returns: the number of column referenced in a given #GdaDataModel. If negative
+ * no column is referenced or no #GdaDataModel is used by @node.
+ *
+ * Since: 5.2
+ */
+gint
+gda_set_node_get_source_column (GdaSetNode *node)
+{
+	g_return_val_if_fail (node, -1);
+	return node->source_column;
+}
+
+/**
+ * gda_set_node_set_source_column:
+ * @node: a #GdaSetNode struct to set column source to, from an used data model 
+ * 
+ * Set column number in the #GdaDataModel used @node. If no #GdaDataModel is set
+ * then column is set to invalid (-1);
+ *
+ * Since: 5.2
+ */
+void
+gda_set_node_set_source_column (GdaSetNode *node, gint column)
+{
+	g_return_if_fail (column >= 0);
+	if (GDA_IS_DATA_MODEL (node->source_model)) {
+		if (column < gda_data_model_get_n_columns (node->source_model))
+			node->source_column = column;
+	}
+}
+
 /* 
  * Main static functions 
  */
@@ -75,7 +657,8 @@ enum
 	PROP_ID,
 	PROP_NAME,
 	PROP_DESCR,
-	PROP_HOLDERS
+	PROP_HOLDERS,
+	PROP_VALIDATE_CHANGES
 };
 
 /* signals */
@@ -103,6 +686,7 @@ struct _GdaSetPrivate
 	GHashTable      *holders_hash; /* key = GdaHoler ID, value = GdaHolder */
 	GArray          *holders_array;
 	gboolean         read_only;
+	gboolean         validate_changes;
 };
 
 static void 
@@ -130,11 +714,29 @@ gda_set_set_property (GObject *object,
 	case PROP_HOLDERS: {
 		/* add the holders */
 		GSList* holders;
-		for (holders = (GSList*) g_value_get_pointer(value); holders; holders = holders->next) 
+		for (holders = (GSList*) g_value_get_pointer (value); holders; holders = holders->next) 
 			gda_set_real_add_holder (set, GDA_HOLDER (holders->data));
 		compute_public_data (set);	
 		break;
 	}
+	case PROP_VALIDATE_CHANGES:
+		if (set->priv->validate_changes != g_value_get_boolean (value)) {
+			GSList *list;
+			set->priv->validate_changes = g_value_get_boolean (value);
+			for (list = set->holders; list; list = list->next) {
+				GdaHolder *holder = (GdaHolder*) list->data;
+				g_object_set ((GObject*) holder, "validate-changes",
+					      set->priv->validate_changes, NULL);
+				if (set->priv->validate_changes)
+					g_signal_connect ((GObject*) holder, "validate-change",
+							  G_CALLBACK (validate_change_holder_cb), set);
+				else
+					g_signal_handlers_disconnect_by_func ((GObject*) holder,
+									      G_CALLBACK (validate_change_holder_cb),
+									      set);
+			}
+		}
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -163,6 +765,9 @@ gda_set_get_property (GObject *object,
 	case PROP_DESCR:
 		g_value_set_string (value, set->priv->descr);
 		break;
+	case PROP_VALIDATE_CHANGES:
+		g_value_set_boolean (value, set->priv->validate_changes);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -185,7 +790,7 @@ gda_set_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaSetClass),
 			(GBaseInitFunc) NULL,
@@ -199,10 +804,10 @@ gda_set_get_type (void)
 			0
 		};
 		
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaSet", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 
 	return type;
@@ -252,7 +857,7 @@ gda_set_class_init (GdaSetClass *class)
 			      GDA_TYPE_HOLDER);
 
 	/**
-	 * GdaSet::validate-holder-change
+	 * GdaSet::validate-holder-change:
 	 * @set: the #GdaSet
 	 * @holder: the #GdaHolder which is going to change
 	 * @new_value: the proposed new value for @holder
@@ -272,7 +877,7 @@ gda_set_class_init (GdaSetClass *class)
 			      _gda_marshal_ERROR__OBJECT_VALUE, G_TYPE_ERROR, 2,
 			      GDA_TYPE_HOLDER, G_TYPE_VALUE);
 	/**
-	 * GdaSet::validate-set
+	 * GdaSet::validate-set:
 	 * @set: the #GdaSet
 	 * 
 	 * Gets emitted when gda_set_is_valid() is called, use
@@ -289,7 +894,7 @@ gda_set_class_init (GdaSetClass *class)
 			      validate_accumulator, NULL,
 			      _gda_marshal_ERROR__VOID, G_TYPE_ERROR, 0);
 	/**
-	 * GdaSet::holder-attr-changed
+	 * GdaSet::holder-attr-changed:
 	 * @set: the #GdaSet
 	 * @holder: the GdaHolder for which an attribute changed
 	 * @attr_name: attribute's name
@@ -306,7 +911,7 @@ gda_set_class_init (GdaSetClass *class)
 			      _gda_marshal_VOID__OBJECT_STRING_VALUE, G_TYPE_NONE, 3,
 			      GDA_TYPE_HOLDER, G_TYPE_STRING, G_TYPE_VALUE);
 	/**
-	 * GdaSet::public-data-changed
+	 * GdaSet::public-data-changed:
 	 * @set: the #GdaSet
 	 * 
 	 * Gets emitted when @set's public data (#GdaSetNode, #GdaSetGroup or #GdaSetSource values) have changed
@@ -320,7 +925,7 @@ gda_set_class_init (GdaSetClass *class)
 			      _gda_marshal_VOID__VOID, G_TYPE_NONE, 0);
 
 	/**
-	 * GdaSet::holder-type-set
+	 * GdaSet::holder-type-set:
 	 * @set: the #GdaSet
 	 * @holder: the #GdaHolder for which the #GType has been set
 	 *
@@ -339,7 +944,7 @@ gda_set_class_init (GdaSetClass *class)
 			      GDA_TYPE_HOLDER);
 
 	/**
-	 * GdaSet::source-model-changed
+	 * GdaSet::source-model-changed:
 	 * @set: the #GdaSet
 	 * @source: the #GdaSetSource for which the @data_model attribute has changed
 	 *
@@ -381,7 +986,18 @@ gda_set_class_init (GdaSetClass *class)
 					 g_param_spec_pointer ("holders", "GSList of GdaHolders", 
 							       "GdaHolder objects the set should contain", (
 								G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY)));
-  
+	/**
+	 * GdaSet:validate-changes:
+	 *
+	 * Defines if the "validate-set" signal gets emitted when
+	 * any holder in the data set changes. This property also affects the
+	 * GdaHolder:validate-changes property.
+	 *
+	 * Since: 5.2.0
+	 */
+	g_object_class_install_property (object_class, PROP_VALIDATE_CHANGES,
+					 g_param_spec_boolean ("validate-changes", NULL, "Defines if the validate-set signal is emitted", TRUE,
+							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	object_class->dispose = gda_set_dispose;
 	object_class->finalize = gda_set_finalize;
 }
@@ -397,6 +1013,7 @@ gda_set_init (GdaSet *set)
 	set->priv->holders_hash = g_hash_table_new (g_str_hash, g_str_equal);
 	set->priv->holders_array = NULL;
 	set->priv->read_only = FALSE;
+	set->priv->validate_changes = TRUE;
 }
 
 
@@ -533,11 +1150,7 @@ gda_set_new_inline (gint nb, ...)
 		else if (type == GDA_TYPE_USHORT)
 			gda_value_set_ushort (value, va_arg (ap, guint));
 		else if (type == G_TYPE_CHAR)
-#if GLIB_CHECK_VERSION(2,31,7)
 			g_value_set_schar (value, va_arg (ap, gint));
-#else
-			g_value_set_char (value, va_arg (ap, int));
-#endif
 		else if (type == G_TYPE_UCHAR)
 			g_value_set_uchar (value, va_arg (ap, guint));
 		else if (type == G_TYPE_FLOAT)
@@ -641,11 +1254,7 @@ gda_set_set_holder_value (GdaSet *set, GError **error, const gchar *holder_id, .
 	else if (type == GDA_TYPE_USHORT)
 		gda_value_set_ushort (value, va_arg (ap, guint));
 	else if (type == G_TYPE_CHAR)
-#if GLIB_CHECK_VERSION(2,31,7)
 		g_value_set_schar (value, va_arg (ap, gint));
-#else
-		g_value_set_char (value, va_arg (ap, int));
-#endif
 	else if (type == G_TYPE_UCHAR)
 		g_value_set_uchar (value, va_arg (ap, guint));
 	else if (type == G_TYPE_FLOAT)
@@ -656,6 +1265,10 @@ gda_set_set_holder_value (GdaSet *set, GError **error, const gchar *holder_id, .
 		gda_value_set_numeric (value, va_arg (ap, GdaNumeric *));
 	else if (type == G_TYPE_DATE)
 		g_value_set_boxed (value, va_arg (ap, GDate *));
+	else if (type == GDA_TYPE_TIMESTAMP)
+		gda_value_set_timestamp (value, va_arg (ap, GdaTimestamp*));
+	else if (type == GDA_TYPE_TIME)
+		gda_value_set_time (value, va_arg (ap, GdaTime*));
 	else if (type == G_TYPE_LONG)
 		g_value_set_long (value, va_arg (ap, glong));
 	else if (type == G_TYPE_ULONG)
@@ -681,7 +1294,7 @@ gda_set_set_holder_value (GdaSet *set, GError **error, const gchar *holder_id, .
  *
  * Get the value of the #GdaHolder which ID is @holder_id
  *
- * Returns: (transfer none): the requested GValue, or %NULL (see gda_holder_get_value())
+ * Returns: (allow-none) (transfer none): the requested GValue, or %NULL (see gda_holder_get_value())
  */
 const GValue *
 gda_set_get_holder_value (GdaSet *set, const gchar *holder_id)
@@ -815,7 +1428,7 @@ gda_set_new_from_spec_string (const gchar *xml_spec, GError **error)
 
 /**
  * gda_set_new_from_spec_node:
- * @xml_spec: a #xmlNodePtr for a &lt;holders&gt; tag
+ * @xml_spec: a #xmlNodePtr for a &lt;parameters&gt; tag
  * @error: (allow-none): a place to store the error, or %NULL
  *
  * Creates a new #GdaSet object from the @xml_spec
@@ -988,13 +1601,15 @@ void
 gda_set_remove_holder (GdaSet *set, GdaHolder *holder)
 {
 	GdaSetNode *node;
+	GdaDataModel *model;
 
 	g_return_if_fail (GDA_IS_SET (set));
 	g_return_if_fail (set->priv);
 	g_return_if_fail (g_slist_find (set->holders, holder));
 
-	g_signal_handlers_disconnect_by_func (G_OBJECT (holder),
-					      G_CALLBACK (validate_change_holder_cb), set);
+	if (set->priv->validate_changes)
+		g_signal_handlers_disconnect_by_func (G_OBJECT (holder),
+						      G_CALLBACK (validate_change_holder_cb), set);
 	if (! set->priv->read_only) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (holder),
 						      G_CALLBACK (changed_holder_cb), set);
@@ -1009,13 +1624,16 @@ gda_set_remove_holder (GdaSet *set, GdaHolder *holder)
 	/* now destroy the GdaSetNode and the GdaSetSource if necessary */
 	node = gda_set_get_node (set, holder);
 	g_assert (node);
-	if (node->source_model) {
+	model = gda_set_node_get_data_model (node);
+	if (GDA_IS_DATA_MODEL (model)) {
 		GdaSetSource *source;
+		GSList *nodes;
 
-		source = gda_set_get_source_for_model (set, node->source_model);
+		source = gda_set_get_source_for_model (set, model);
 		g_assert (source);
-		g_assert (source->nodes);
-		if (! source->nodes->next)
+		nodes = gda_set_source_get_nodes (source);
+		g_assert (nodes);
+		if (! nodes->next)
 			set_remove_source (set, source);
 	}
 	set_remove_node (set, node);
@@ -1082,8 +1700,7 @@ changed_holder_cb (GdaHolder *holder, GdaSet *set)
 static void
 group_free (GdaSetGroup *group, G_GNUC_UNUSED gpointer data)
 {
-	g_slist_free (group->nodes);
-	g_free (group);
+	gda_set_group_free (group);
 }
 
 static void
@@ -1099,8 +1716,9 @@ gda_set_dispose (GObject *object)
 	/* free the holders list */
 	if (set->holders) {
 		for (list = set->holders; list; list = list->next) {
-			g_signal_handlers_disconnect_by_func (G_OBJECT (list->data),
-							      G_CALLBACK (validate_change_holder_cb), set);
+			if (set->priv->validate_changes)
+				g_signal_handlers_disconnect_by_func (G_OBJECT (list->data),
+								      G_CALLBACK (validate_change_holder_cb), set);
 			if (! set->priv->read_only) {
 				g_signal_handlers_disconnect_by_func (G_OBJECT (list->data),
 								      G_CALLBACK (changed_holder_cb), set);
@@ -1185,13 +1803,11 @@ compute_public_data (GdaSet *set)
 	 * Creation of the GdaSetNode structures
 	 */
 	for (list = set->holders; list; list = list->next) {
-		node = g_new0 (GdaSetNode, 1);
-		node->holder = GDA_HOLDER (list->data);
-		node->source_model = gda_holder_get_source_model (node->holder,
-								  &(node->source_column));
-		if (node->source_model)
-			g_object_ref (node->source_model);
-		
+		GdaHolder *holder = GDA_HOLDER (list->data);
+		gint col;
+		node = gda_set_node_new (holder);
+		gda_set_node_set_data_model (node, gda_holder_get_source_model (holder, &col));
+		gda_set_node_set_source_column (node, col);
 		set->nodes_list = g_slist_prepend (set->nodes_list, node);
 	}
 	set->nodes_list = g_slist_reverse (set->nodes_list);
@@ -1204,34 +1820,32 @@ compute_public_data (GdaSet *set)
 		
 		/* source */
 		source = NULL;
-		if (node->source_model) {
-			source = gda_set_get_source_for_model (set, node->source_model);
-			if (source) 
-				source->nodes = g_slist_append (source->nodes, node);
+		if (gda_set_node_get_data_model (node)) {
+			source = gda_set_get_source_for_model (set, gda_set_node_get_data_model (node));
+			if (source)
+				gda_set_source_add_node (source, node);
 			else {
-				source = g_new0 (GdaSetSource, 1);
-				source->data_model = node->source_model;
-				source->nodes = g_slist_append (NULL, node);
+				source = gda_set_source_new (gda_set_node_get_data_model (node));
+				gda_set_source_add_node (source, node);
 				set->sources_list = g_slist_prepend (set->sources_list, source);
 			}
 		}
 
 		/* group */
 		group = NULL;
-		if (node->source_model && groups)
-			group = g_hash_table_lookup (groups, node->source_model);
+		if (gda_set_node_get_data_model (node) && groups)
+			group = g_hash_table_lookup (groups, gda_set_node_get_data_model (node));
 		if (group) 
-			group->nodes = g_slist_append (group->nodes, node);
+			gda_set_group_add_node (group, node);
 		else {
-			group = g_new0 (GdaSetGroup, 1);
-			group->nodes = g_slist_append (NULL, node);
-			group->nodes_source = source;
+			group = gda_set_group_new (node);
+			gda_set_group_set_source (group, source);
 			set->groups_list = g_slist_prepend (set->groups_list, group);
-			if (node->source_model) {
+			if (gda_set_node_get_data_model (node)) {
 				if (!groups)
 					groups = g_hash_table_new (NULL, NULL); /* key = source model, 
-										   value = GdaSetGroup */
-				g_hash_table_insert (groups, node->source_model, group);
+                                                               value = GdaSetGroup */
+				g_hash_table_insert (groups, gda_set_node_get_data_model (node), group);
 			}
 		}		
 	}
@@ -1332,8 +1946,9 @@ gda_set_real_add_holder (GdaSet *set, GdaHolder *holder)
 			set->priv->holders_array = NULL;
 		}
 		g_object_ref (holder);
-		g_signal_connect (G_OBJECT (holder), "validate-change",
-				  G_CALLBACK (validate_change_holder_cb), set);
+		if (set->priv->validate_changes)
+			g_signal_connect (G_OBJECT (holder), "validate-change",
+					  G_CALLBACK (validate_change_holder_cb), set);
 		if (! set->priv->read_only) {
 			g_signal_connect (G_OBJECT (holder), "changed",
 					  G_CALLBACK (changed_holder_cb), set);
@@ -1387,24 +2002,16 @@ static void
 set_remove_node (GdaSet *set, GdaSetNode *node)
 {
 	g_return_if_fail (g_slist_find (set->nodes_list, node));
-
-	if (node->source_model)
-		g_object_unref (G_OBJECT (node->source_model));
-
+	gda_set_node_free (node);
 	set->nodes_list = g_slist_remove (set->nodes_list, node);
-	g_free (node);
 }
 
 static void
 set_remove_source (GdaSet *set, GdaSetSource *source)
 {
 	g_return_if_fail (g_slist_find (set->sources_list, source));
-
-	if (source->nodes)
-		g_slist_free (source->nodes);
-
+	gda_set_source_free (source);
 	set->sources_list = g_slist_remove (set->sources_list, source);
-	g_free (source);
 }
 
 /**
@@ -1429,7 +2036,7 @@ gda_set_is_valid (GdaSet *set, GError **error)
 	g_return_val_if_fail (set->priv, FALSE);
 
 	for (holders = set->holders; holders; holders = holders->next) {
-		if (!gda_holder_is_valid ((GdaHolder*) holders->data)) {
+		if (!gda_holder_is_valid (GDA_HOLDER (holders->data))) {
 			g_set_error (error, GDA_SET_ERROR, GDA_SET_INVALID_ERROR,
 				     "%s", _("One or more values are invalid"));
 			return FALSE;
@@ -1525,13 +2132,18 @@ gda_set_get_node (GdaSet *set, GdaHolder *holder)
 	g_return_val_if_fail (GDA_IS_SET (set), NULL);
 	g_return_val_if_fail (set->priv, NULL);
 	g_return_val_if_fail (GDA_IS_HOLDER (holder), NULL);
+	/* FIXME: May is better to use holder's hash for better performance */
 	g_return_val_if_fail (g_slist_find (set->holders, holder), NULL);
 
 	for (list = set->nodes_list; list && !retval; list = list->next) {
-		if (GDA_SET_NODE (list->data)->holder == holder)
-			retval = GDA_SET_NODE (list->data);
+		GdaHolder *node_holder;
+		retval = GDA_SET_NODE (list->data);
+		node_holder = gda_set_node_get_holder (retval);
+		if (node_holder == holder) /* FIXME: May is better to compare holders ID */
+			break;
+		else
+			retval = NULL;
 	}
-
 	return retval;
 }
 
@@ -1549,10 +2161,12 @@ GdaSetSource *
 gda_set_get_source (GdaSet *set, GdaHolder *holder)
 {
 	GdaSetNode *node;
-	
+	GdaDataModel *node_model;
+
 	node = gda_set_get_node (set, holder);
-	if (node && node->source_model)
-		return gda_set_get_source_for_model (set, node->source_model);
+	node_model = gda_set_node_get_data_model (node);
+	if (node && GDA_IS_DATA_MODEL (node_model))
+		return gda_set_get_source_for_model (set, node_model);
 	else
 		return NULL;
 }
@@ -1570,24 +2184,33 @@ gda_set_get_source (GdaSet *set, GdaHolder *holder)
 GdaSetGroup *
 gda_set_get_group (GdaSet *set, GdaHolder *holder)
 {
+	GdaSetNode *node;
 	GdaSetGroup *retval = NULL;
 	GSList *list, *sublist;
+	GdaHolder *node_holder;
 
 	g_return_val_if_fail (GDA_IS_SET (set), NULL);
 	g_return_val_if_fail (set->priv, NULL);
 	g_return_val_if_fail (GDA_IS_HOLDER (holder), NULL);
+	/* FIXME: May is better to use holder's hash for better performance */
 	g_return_val_if_fail (g_slist_find (set->holders, holder), NULL);
 
 	for (list = set->groups_list; list && !retval; list = list->next) {
-		sublist = GDA_SET_GROUP (list->data)->nodes;
+		retval = GDA_SET_GROUP (list->data);
+		sublist = gda_set_group_get_nodes (retval);
 		while (sublist && !retval) {
-			if (GDA_SET_NODE (sublist->data)->holder == holder)
-				retval = GDA_SET_GROUP (list->data);
-			else
-				sublist = g_slist_next (sublist);	
+			node = GDA_SET_NODE (sublist->data);
+			if (node) {
+				node_holder = gda_set_node_get_holder (node);
+				if (node_holder == holder) /* FIXME: May is better to compare holders ID */
+					break;
+				else {
+					sublist = g_slist_next (sublist);
+					retval = NULL;
+				}
+			}
 		}
 	}
-
 	return retval;
 }
 
@@ -1606,6 +2229,7 @@ GdaSetSource *
 gda_set_get_source_for_model (GdaSet *set, GdaDataModel *model)
 {
 	GdaSetSource *retval = NULL;
+	GdaDataModel *source_model;
 	GSList *list;
 
 	g_return_val_if_fail (GDA_IS_SET (set), NULL);
@@ -1614,9 +2238,14 @@ gda_set_get_source_for_model (GdaSet *set, GdaDataModel *model)
 
 	list = set->sources_list;
 	while (list && !retval) {
-		if (GDA_SET_SOURCE (list->data)->data_model == model)
-			retval = GDA_SET_SOURCE (list->data);
-
+		retval = GDA_SET_SOURCE (list->data);
+		source_model = gda_set_source_get_data_model (retval);
+		if (GDA_IS_DATA_MODEL (source_model)) {
+			if (source_model == model)
+				break;
+			else 
+				retval = NULL;
+		}
 		list = g_slist_next (list);
 	}
 
@@ -1624,7 +2253,7 @@ gda_set_get_source_for_model (GdaSet *set, GdaDataModel *model)
 }
 
 /**
- * gda_set_replace_source_model
+ * gda_set_replace_source_model:
  * @set: a #GdaSet object
  * @source: a pointer to a #GdaSetSource in @set
  * @model: a #GdaDataModel
@@ -1641,6 +2270,8 @@ gda_set_get_source_for_model (GdaSet *set, GdaDataModel *model)
 void
 gda_set_replace_source_model (GdaSet *set, GdaSetSource *source, GdaDataModel *model)
 {
+	GdaDataModel *source_model;
+	
 	g_return_if_fail (GDA_IS_SET (set));
 	g_return_if_fail (source);
 	g_return_if_fail (g_slist_find (set->sources_list, source));
@@ -1648,34 +2279,40 @@ gda_set_replace_source_model (GdaSet *set, GdaSetSource *source, GdaDataModel *m
 	
 	/* compare models */
 	gint ncols, i;
-	ncols = gda_data_model_get_n_columns (source->data_model);
-	if (ncols != gda_data_model_get_n_columns (model)) {
-		g_warning (_("Replacing data model must have the same characteristics as the "
-			     "data model it replaces"));
-		return;
-	}
-	for (i = 0; i < ncols; i++) {
-		GdaColumn *c1, *c2;
-		GType t1, t2;
-		c1 = gda_data_model_describe_column (source->data_model, i);
-		c2 = gda_data_model_describe_column (model, i);
-		t1 = gda_column_get_g_type (c1);
-		t2 = gda_column_get_g_type (c2);
 
-		if ((t1 != GDA_TYPE_NULL) && (t2 != GDA_TYPE_NULL) && (t1 != t2)) {
+	source_model = gda_set_source_get_data_model (source);
+	if (GDA_IS_DATA_MODEL (source_model)) {
+		ncols = gda_data_model_get_n_columns (source_model);
+		/* FIXME: This way to compare two Data Models could be useful as a function
+		 * gda_data_model_compare (GdaDataModel)
+		 **/
+		if (ncols != gda_data_model_get_n_columns (model)) {
 			g_warning (_("Replacing data model must have the same characteristics as the "
-				     "data model it replaces"));
+					 "data model it replaces"));
 			return;
 		}
+		for (i = 0; i < ncols; i++) {
+			GdaColumn *c1, *c2;
+			GType t1, t2;
+			c1 = gda_data_model_describe_column (source->data_model, i);
+			c2 = gda_data_model_describe_column (model, i);
+			t1 = gda_column_get_g_type (c1);
+			t2 = gda_column_get_g_type (c2);
+
+			if ((t1 != GDA_TYPE_NULL) && (t2 != GDA_TYPE_NULL) && (t1 != t2)) {
+				g_warning (_("Replacing data model must have the same characteristics as the "
+						 "data model it replaces"));
+				return;
+			}
+		}
 	}
 
 	/* actually swap the models */
 	GSList *list;
-	source->data_model = model;
-	for (list = source->nodes; list; list = list->next) {
-		GdaSetNode *node = (GdaSetNode*) list->data;
-		g_object_unref (node->source_model);
-		node->source_model = g_object_ref (model);
+	gda_set_source_set_data_model (source, model);
+	for (list = gda_set_source_get_nodes (source); list; list = list->next) {
+		GdaSetNode *node = GDA_SET_NODE (list->data);
+		gda_set_node_set_data_model (node, model);
 		g_signal_handlers_block_by_func (G_OBJECT (node->holder),
 						 G_CALLBACK (source_changed_holder_cb), set);
 		gda_holder_set_source_model (GDA_HOLDER (node->holder), model, node->source_column,
@@ -1692,3 +2329,60 @@ gda_set_replace_source_model (GdaSet *set, GdaSetSource *source, GdaDataModel *m
 	g_print ("<< 'SOURCE_MODEL_CHANGED' from %s\n", __FUNCTION__);
 #endif
 }
+
+#ifdef GDA_DEBUG_NO
+static void holder_dump (GdaHolder *holder);
+static void set_node_dump (GdaSetNode *node);
+static void set_source_dump (GdaSetSource *source);
+static void set_group_dump (GdaSetGroup *group);
+
+static void
+holder_dump (GdaHolder *holder)
+{
+	g_print ("  GdaHolder %p (%s)\n", holder, holder ? gda_holder_get_id (holder) : "---");
+}
+
+static void
+set_source_dump (GdaSetSource *source)
+{
+	g_print ("  GdaSetSource %p\n", source);
+	if (source) {
+		g_print ("    - data_model: %p\n", source->data_model);
+		GSList *list;
+		for (list = source->nodes; list; list = list->next)
+			g_print ("    - node: %p\n", list->data);
+	}
+}
+
+static void
+set_group_dump (GdaSetGroup *group)
+{
+	g_print ("  GdaSetGroup %p\n", group);
+	if (group) {
+		GSList *list;
+		for (list = gda_set_group_get_nodes (group); list; list = list->next)
+			g_print ("    - node: %p\n", list->data);
+		g_print ("    - GdaSetSource: %p\n", group->nodes_source);
+	}
+}
+
+static void
+set_node_dump (GdaSetNode *node)
+{
+	g_print ("  GdaSetNode: %p\n", node);
+	g_print ("   - holder: %p (%s)\n", node->holder, node->holder ? gda_holder_get_id (node->holder) : "ERROR : no GdaHolder!");
+	g_print ("   - source_model: %p\n", node->source_model);
+	g_print ("   - source_column: %d\n", node->source_column);
+}
+
+void
+gda_set_dump (GdaSet *set)
+{
+	g_print ("=== GdaSet %p ===\n", set);
+	g_slist_foreach (set->holders, (GFunc) holder_dump, NULL);
+	g_slist_foreach (set->nodes_list, (GFunc) set_node_dump, NULL);
+	g_slist_foreach (set->sources_list, (GFunc) set_source_dump, NULL);
+	g_slist_foreach (set->groups_list, (GFunc) set_group_dump, NULL);
+	g_print ("=== GdaSet %p END ===\n", set);
+}
+#endif
