@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
  *
@@ -102,7 +102,7 @@ gda_statement_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaStatementClass),
 			(GBaseInitFunc) NULL,
@@ -116,10 +116,10 @@ gda_statement_get_type (void)
 			0
 		};
 		
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaStatement", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -131,10 +131,9 @@ gda_statement_class_init (GdaStatementClass * klass)
 	parent_class = g_type_class_peek_parent (klass);
 
 	/**
-	 * GdaStatement::reset
-	 * @stmt: the #GdaStatement object
+	 * GdaStatement::reset:
 	 *
-	 * Gets emitted whenever the @stmt has changed
+	 * Gets emitted whenever the statement has changed
 	 */
 	gda_statement_signals[RESET] =
 		g_signal_new ("reset",
@@ -145,11 +144,10 @@ gda_statement_class_init (GdaStatementClass * klass)
 			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE,
 			      0);
 	/**
-	 * GdaStatement::checked
-	 * @stmt: the #GdaStatement object
+	 * GdaStatement::checked:
 	 *
 	 * Gets emitted whenever the structure and contents
-	 * of @stmt have been verified (emitted after gda_statement_check_validity()).
+	 * of the statement have been verified (emitted after gda_statement_check_validity()).
 	 */
 	gda_statement_signals[CHECKED] =
 		g_signal_new ("checked",
@@ -796,6 +794,43 @@ default_render_value (const GValue *value, GdaSqlRenderingContext *context, GErr
 				return NULL;
 			}
 		}
+		if (context->flags & GDA_STATEMENT_SQL_TIMEZONE_TO_GMT) {
+			if (G_VALUE_TYPE (value) == GDA_TYPE_TIME) {
+				GdaTime *nts;
+				nts = (GdaTime*) gda_value_get_time (value);
+				if (nts && (nts->timezone != GDA_TIMEZONE_INVALID)) {
+					nts = gda_time_copy (nts);
+					gda_time_change_timezone (nts, 0);
+					nts->timezone = GDA_TIMEZONE_INVALID;
+					GValue v = {0};
+					g_value_init (&v, GDA_TYPE_TIME);
+					gda_value_set_time (&v, nts);
+					gda_time_free (nts);
+					gchar *tmp;
+					tmp = gda_data_handler_get_sql_from_value (dh, &v);
+					g_value_reset (&v);
+					return tmp;
+				}
+			}
+			else if (G_VALUE_TYPE (value) == GDA_TYPE_TIMESTAMP) {
+				GdaTimestamp *nts;
+				nts = (GdaTimestamp*) gda_value_get_timestamp (value);
+				if (nts && (nts->timezone != GDA_TIMEZONE_INVALID)) {
+					nts = gda_timestamp_copy (nts);
+					gda_timestamp_change_timezone (nts, 0);
+					nts->timezone = GDA_TIMEZONE_INVALID;
+					GValue v = {0};
+					g_value_init (&v, GDA_TYPE_TIMESTAMP);
+					gda_value_set_timestamp (&v, nts);
+					gda_timestamp_free (nts);
+					gchar *tmp;
+					tmp = gda_data_handler_get_sql_from_value (dh, &v);
+					g_value_reset (&v);
+					return tmp;
+				}
+			}
+		}
+
 		return gda_data_handler_get_sql_from_value (dh, value);
 	}
 	else
@@ -1492,8 +1527,8 @@ default_render_expr (GdaSqlExpr *expr, GdaSqlRenderingContext *context, gboolean
 	if (is_null)
 		*is_null = FALSE;
 
-	/* can't have: 
-	 *  - expr->cast_as && expr->param_spec 
+	/* can't have:
+	 *  - expr->cast_as && expr->param_spec
 	 */
 	if (!gda_sql_any_part_check_structure (GDA_SQL_ANY_PART (expr), error)) return NULL;
 
@@ -1639,7 +1674,7 @@ default_render_expr (GdaSqlExpr *expr, GdaSqlRenderingContext *context, gboolean
 
 	if (!str) goto err;
 
-	if (expr->cast_as) 
+	if (expr->cast_as)
 		g_string_append_printf (string, "CAST (%s AS %s)", str, expr->cast_as);
 	else
 		g_string_append (string, str);
@@ -1803,9 +1838,15 @@ default_render_operation (GdaSqlOperation *op, GdaSqlRenderingContext *context,
 	case GDA_SQL_OPERATOR_TYPE_LIKE:
 		str = g_strdup_printf ("%s LIKE %s", SQL_OPERAND (sql_list->data)->sql, SQL_OPERAND (sql_list->next->data)->sql);
 		break;
+	case GDA_SQL_OPERATOR_TYPE_NOTLIKE:
+		str = g_strdup_printf ("%s NOT LIKE %s", SQL_OPERAND (sql_list->data)->sql, SQL_OPERAND (sql_list->next->data)->sql);
+		break;
 	case GDA_SQL_OPERATOR_TYPE_ILIKE:
 		str = g_strdup_printf ("%s ILIKE %s", SQL_OPERAND (sql_list->data)->sql, SQL_OPERAND (sql_list->next->data)->sql);
 		break;
+	case GDA_SQL_OPERATOR_TYPE_NOTILIKE:
+		str = g_strdup_printf ("%s NOT ILIKE %s", SQL_OPERAND (sql_list->data)->sql, SQL_OPERAND (sql_list->next->data)->sql);
+		break;
 	case GDA_SQL_OPERATOR_TYPE_GT:
 		str = g_strdup_printf ("%s > %s", SQL_OPERAND (sql_list->data)->sql, SQL_OPERAND (sql_list->next->data)->sql);
 		break;
@@ -1908,6 +1949,9 @@ default_render_operation (GdaSqlOperation *op, GdaSqlRenderingContext *context,
 	case GDA_SQL_OPERATOR_TYPE_OR:
 		multi_op = "OR";
 		break;
+	case GDA_SQL_OPERATOR_TYPE_GLOB:
+		str = g_strdup_printf ("%s GLOB %s", SQL_OPERAND (sql_list->data)->sql, SQL_OPERAND (sql_list->next->data)->sql);
+		break;
 	default:
 		g_assert_not_reached ();
 		break;
