@@ -1,7 +1,8 @@
 /*
  * Copyright (C) 2008 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2009 - 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2009 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2011 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -311,7 +312,11 @@ typedef enum {
 	GDA_SQL_OPERATOR_TYPE_BITAND,
 	GDA_SQL_OPERATOR_TYPE_BITOR,
 	GDA_SQL_OPERATOR_TYPE_BITNOT,
-	GDA_SQL_OPERATOR_TYPE_ILIKE
+	GDA_SQL_OPERATOR_TYPE_ILIKE,
+
+	GDA_SQL_OPERATOR_TYPE_NOTLIKE,
+	GDA_SQL_OPERATOR_TYPE_NOTILIKE,
+	GDA_SQL_OPERATOR_TYPE_GLOB
 } GdaSqlOperatorType;
 
 /**
