@@ -88,12 +88,12 @@ _remove_quotes (gchar *str)
         total = strlen (str);
         if (str[total-1] == delim) {
 		/* string is correctly terminated by a double quote */
-		g_memmove (str, str+1, total-2);
+		memmove (str, str+1, total-2);
 		total -=2;
 	}
 	else {
 		/* string is _not_ correctly terminated by a double quote */
-		g_memmove (str, str+1, total-1);
+		memmove (str, str+1, total-1);
 		total -=1;
 	}
         str[total] = 0;
@@ -103,7 +103,7 @@ _remove_quotes (gchar *str)
                 /* we accept the "''" as a synonym of "\'" */
                 if (*ptr == delim) {
                         if (*(ptr+1) == delim) {
-                                g_memmove (ptr+1, ptr+2, total - offset);
+                                memmove (ptr+1, ptr+2, total - offset);
                                 offset += 2;
                         }
                         else {
@@ -113,7 +113,7 @@ _remove_quotes (gchar *str)
                 }
                 else if (*ptr == '"') {
                         if (*(ptr+1) == '"') {
-                                g_memmove (ptr+1, ptr+2, total - offset);
+                                memmove (ptr+1, ptr+2, total - offset);
                                 offset += 2;
                         }
                         else {
@@ -123,13 +123,13 @@ _remove_quotes (gchar *str)
                 }
 		else if (*ptr == '\\') {
                         if (*(ptr+1) == '\\') {
-                                g_memmove (ptr+1, ptr+2, total - offset);
+                                memmove (ptr+1, ptr+2, total - offset);
                                 offset += 2;
                         }
                         else {
                                 if (*(ptr+1) == delim) {
                                         *ptr = delim;
-                                        g_memmove (ptr+1, ptr+2, total - offset);
+                                        memmove (ptr+1, ptr+2, total - offset);
                                         offset += 2;
                                 }
                                 else {
