@@ -249,6 +249,7 @@ virtual_filtered_data_new (VirtualTable *vtable, GdaDataModel *model,
 static void
 virtual_filtered_data_free (VirtualFilteredData *data)
 {
+	g_return_if_fail (data != NULL);
 	if (data->argv) {
 		int i;
 		for (i = 0; i < data->argc; i++)
@@ -279,6 +280,7 @@ virtual_filtered_data_free (VirtualFilteredData *data)
 static VirtualFilteredData *
 virtual_filtered_data_ref (VirtualFilteredData *data)
 {
+	g_return_val_if_fail (data != NULL, NULL);
 	data->refcount ++;
 	return data;
 }
@@ -286,6 +288,7 @@ virtual_filtered_data_ref (VirtualFilteredData *data)
 void
 _gda_vconnection_virtual_filtered_data_unref (VirtualFilteredData *data)
 {
+	g_return_if_fail (data != NULL);
 	data->refcount --;
 	if (data->refcount == 0)
 		virtual_filtered_data_free (data);
@@ -298,6 +301,7 @@ virtual_cursor_free (VirtualCursor *cursor)
 		return;
 
 	_gda_vconnection_virtual_filtered_data_unref (cursor->data);
+	cursor->data = NULL;
 	g_free (cursor);
 }
 
@@ -1292,7 +1296,6 @@ map_sqlite3_info_to_gda_filter (sqlite3_index_info *info, GdaVconnectionDataMode
 			if (! info->aConstraint[i].usable)
 				continue;
 
-			filter->aConstraint[j].iColumn = info->aConstraint[i].iColumn;
 			switch (info->aConstraint[i].op) {
 			case SQLITE_INDEX_CONSTRAINT_EQ:
 				filter->aConstraint[j].op = GDA_SQL_OPERATOR_TYPE_EQ;
@@ -1312,9 +1315,18 @@ map_sqlite3_info_to_gda_filter (sqlite3_index_info *info, GdaVconnectionDataMode
 			case SQLITE_INDEX_CONSTRAINT_MATCH:
 				filter->aConstraint[j].op = GDA_SQL_OPERATOR_TYPE_REGEXP;
 				break;
+#if HAVE_SQLITE
+			case SQLITE_INDEX_CONSTRAINT_LIKE:
+				filter->aConstraint[j].op = GDA_SQL_OPERATOR_TYPE_LIKE;
+				break;
+			case SQLITE_INDEX_CONSTRAINT_GLOB:
+				filter->aConstraint[j].op = GDA_SQL_OPERATOR_TYPE_GLOB;
+				break;
+#endif
 			default:
 				g_assert_not_reached ();
 			}
+			filter->aConstraint[j].iColumn = info->aConstraint[i].iColumn;
 
 			filter->aConstraintUsage[j].argvIndex = 0;
 			filter->aConstraintUsage[j].omit = FALSE;
