@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -33,6 +33,7 @@
 #include "jni-globals.h"
 #include "gda-jdbc-util.h"
 #include "gda-jdbc-recordset.h"
+#include <libgda/gda-debug-macros.h>
 
 /*
  * Meta initialization
@@ -46,15 +47,15 @@ static gboolean
 init_meta_obj (GdaConnection *cnc, JNIEnv *jenv, JdbcConnectionData *cdata, GError **error)
 {
 	GError *lerror = NULL;
-	static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
+	static GMutex init_mutex;
 
-	g_static_mutex_lock (&init_mutex);
+	g_mutex_lock (&init_mutex);
 
 	if (cdata->jmeta_obj)
 		return TRUE;
 	cdata->jmeta_obj = jni_wrapper_method_call (jenv, GdaJConnection__getJMeta,
 						    cdata->jcnc_obj, NULL, NULL, &lerror);
-	g_static_mutex_unlock (&init_mutex);
+	g_mutex_unlock (&init_mutex);
 	if (!cdata->jmeta_obj) {
 		if (error && lerror)
 			*error = g_error_copy (lerror);
