@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2013 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
@@ -40,6 +40,8 @@
 #include "gda-jdbc-util.h"
 #include "jni-wrapper.h"
 #include "jni-globals.h"
+#include "jdbc-resources.h"
+#include <libgda/gda-debug-macros.h>
 
 #define _GDA_PSTMT(x) ((GdaPStmt*)(x))
 
@@ -145,7 +147,8 @@ static void gda_jdbc_free_cnc_data (JdbcConnectionData *cdata);
  * TO_ADD: any prepared statement to be used internally by the provider should be
  *         declared here, as constants and as SQL statements
  */
-static GdaStatement **internal_stmt;
+static GMutex init_mutex;
+static GdaStatement **internal_stmt = NULL;
 
 typedef enum {
 	INTERNAL_STMT1
@@ -266,21 +269,27 @@ extern JavaVM *_jdbc_provider_java_vm;
 static void
 gda_jdbc_provider_init (GdaJdbcProvider *jdbc_prv, G_GNUC_UNUSED GdaJdbcProviderClass *klass)
 {
-	InternalStatementItem i;
-	GdaSqlParser *parser;
+	g_mutex_lock (&init_mutex);
 
-	parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) jdbc_prv);
-	internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
-	for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
-		internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
-		if (!internal_stmt[i]) 
-			g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+	if (!internal_stmt) {
+		InternalStatementItem i;
+		GdaSqlParser *parser;
+
+		parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) jdbc_prv);
+		internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
+		for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
+			internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
+			if (!internal_stmt[i])
+				g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+		}
 	}
 
 	/* meta data init */
 	_gda_jdbc_provider_meta_init ((GdaServerProvider*) jdbc_prv);
 
 	/* TO_ADD: any other provider's init should be added here */
+
+	g_mutex_unlock (&init_mutex);
 }
 
 GType
@@ -289,7 +298,7 @@ gda_jdbc_provider_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static GTypeInfo info = {
 			sizeof (GdaJdbcProviderClass),
 			(GBaseInitFunc) NULL,
@@ -301,10 +310,10 @@ gda_jdbc_provider_get_type (void)
 			(GInstanceInitFunc) gda_jdbc_provider_init,
 			0
 		};
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_SERVER_PROVIDER, "GdaJdbcProvider", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 
 	return type;
@@ -329,6 +338,121 @@ gda_jdbc_provider_get_version (G_GNUC_UNUSED GdaServerProvider *provider)
 	return PACKAGE_VERSION;
 }
 
+/*
+ * make_url_from_params:
+ *
+ * Creates the URL to pass to the JDBC driver to open a connection. It uses the
+ * jdbc_mappings.xml file
+ *
+ * Returns: a new string, or %NULL if not enough information found to create the connection URL
+ */
+static gchar *
+make_url_from_params (GdaServerProvider *provider, GdaConnection *cnc,
+		      GdaQuarkList *params, G_GNUC_UNUSED GdaQuarkList *auth)
+{
+	GBytes *data;
+	const gchar *xmlstr;
+	gsize data_size = 0;
+	_jdbc_register_resource ();
+	data = g_resources_lookup_data ("/jdbc/jdbc-mappings.xml", G_RESOURCE_LOOKUP_FLAGS_NONE, NULL);
+	g_assert (data);
+	xmlstr = g_bytes_get_data (data, &data_size);
+
+	xmlDocPtr doc;
+	doc = xmlParseMemory (xmlstr, data_size);
+	g_bytes_unref (data);
+	_jdbc_unregister_resource ();
+
+        if (!doc)
+		return NULL;
+
+	xmlNodePtr root, node;
+	GString *url = NULL;
+	root = xmlDocGetRootElement (doc);
+	if (strcmp ((gchar*) root->name, "jdbc-mappings"))
+		goto out;
+
+	for (node = root->children; node; node = node->next) {
+                if (strcmp ((gchar *) node->name, "driver"))
+                        continue;
+		xmlChar *prop;
+		prop = xmlGetProp (node, BAD_CAST "name");
+		if (!prop)
+			continue;
+		if (!strcmp ((gchar*) prop, gda_server_provider_get_name (provider))) {
+			xmlFree (prop);
+			break;
+		}
+		xmlFree (prop);
+        }
+	if (!node)
+		goto out;
+
+	url = g_string_new ("");
+	for (node = node->children; node; node = node->next) {
+                if (!strcmp ((gchar *) node->name, "prefix")) {
+			xmlChar *contents;
+			contents = xmlNodeGetContent (node);
+			if (contents && *contents)
+				g_string_append (url, (gchar*) contents);
+		}
+		else if (!strcmp ((gchar *) node->name, "part")) {
+			xmlChar *prop;
+			const gchar *cvarvalue = NULL;
+			gchar *varvalue = NULL;
+			gboolean opt = FALSE;
+			prop = xmlGetProp (node, BAD_CAST "variable");
+			if (prop) {
+				cvarvalue = gda_quark_list_find (params, (gchar*) prop);
+				xmlFree (prop);
+			}
+			prop = xmlGetProp (node, BAD_CAST "optional");
+			if (prop) {
+				if ((*prop == 't') || (*prop == 'T'))
+					opt = TRUE;
+				xmlFree (prop);
+			}
+
+			prop = xmlGetProp (node, BAD_CAST "if");
+			if (prop) {
+				if (!strcmp ((gchar*) prop, "CncReadOnly")) {
+					if (gda_connection_get_options (cnc) & GDA_CONNECTION_OPTIONS_READ_ONLY) {
+						xmlFree (prop);
+						prop = xmlGetProp (node, BAD_CAST "value");
+						if (prop)
+							varvalue = g_strdup ((gchar*) prop);
+					}
+				}
+				if (prop)
+					xmlFree (prop);
+			}
+
+			if (cvarvalue || varvalue) {
+				prop = xmlGetProp (node, BAD_CAST "prefix");
+				if (prop) {
+					g_string_append (url, (gchar*) prop);
+					xmlFree (prop);
+				}
+				g_string_append (url, varvalue ? varvalue : cvarvalue);
+				g_free (varvalue);
+			}
+			else if (!varvalue && !cvarvalue && !opt) {
+				/* missing parameter */
+				g_string_free (url, TRUE);
+				url = NULL;
+				goto out;
+			}
+		}
+        }
+
+ out:
+	xmlFreeDoc (doc);
+	if (url)
+		return g_string_free (url, FALSE);
+	else
+		return NULL;
+}
+
 /* 
  * Open connection request
  *
@@ -358,12 +482,18 @@ gda_jdbc_provider_open_connection (GdaServerProvider *provider, GdaConnection *c
 	}
 
 	/* Check for connection parameters */
-	const gchar *url;
-	url = gda_quark_list_find (params, "URL");
-	if (!url) {
-		gda_connection_add_event_string (cnc,
-						 _("The connection string must contain the URL value"));
-		return FALSE;
+	gchar *url;
+	const gchar *cstr;
+	cstr = gda_quark_list_find (params, "URL");
+	if (cstr)
+		url = g_strdup (cstr);
+	else {
+		url = make_url_from_params (provider, cnc, params, auth);
+		if (!url) {
+			gda_connection_add_event_string (cnc,
+							 _("Missing parameters to open database connection"));
+			return FALSE;
+		}
 	}
 
 	/* Check for username / password */
@@ -390,10 +520,14 @@ gda_jdbc_provider_open_connection (GdaServerProvider *provider, GdaConnection *c
 						 error && error->message ? error->message : _("No detail"));
 		if (error)
 			g_error_free (error);
+		g_free (url);
 		return FALSE;
 	}
 
 	jstr = (*env)->NewStringUTF (env, url);
+	/*g_print ("URL = [%s] USERNAME = [%s] PASSWORD = [%s]\n", url, username, password);*/
+	g_free (url);
+	url = NULL;
 	if (username)
 		jstr1 = (*env)->NewStringUTF (env, username);
 	else
@@ -402,6 +536,7 @@ gda_jdbc_provider_open_connection (GdaServerProvider *provider, GdaConnection *c
 		jstr2 = (*env)->NewStringUTF (env, password);
 	else
 		jstr2 = NULL;
+
 	obj_value = jni_wrapper_method_call (env, GdaJProvider__openConnection, 
 					     jprov->jprov_obj, &error_code, &sql_state, &error,
 					     jstr, jstr1, jstr2);
@@ -475,7 +610,7 @@ gda_jdbc_provider_get_server_version (GdaServerProvider *provider, GdaConnection
 		return FALSE;
 
 	if (! cdata->server_version && cdata->jcnc_obj) {
-		JNIEnv *jenv;
+		JNIEnv *jenv = NULL;
 		gboolean jni_detach;
 		GError *error = NULL;
 
@@ -948,7 +1083,7 @@ gda_jdbc_provider_get_data_handler (GdaServerProvider *provider, GdaConnection *
                 }
 	}
 	else
-		dh = gda_server_provider_get_data_handler_default (provider, cnc, type, dbms_type);
+		dh = gda_server_provider_handler_use_default (provider, type);
 
 	return dh;
 }
@@ -1077,13 +1212,14 @@ gda_jdbc_provider_statement_prepare (GdaServerProvider *provider, GdaConnection
                 return FALSE;
         sql = gda_jdbc_provider_statement_to_sql (provider, cnc, stmt, params, GDA_STATEMENT_SQL_PARAMS_AS_UQMARK,
 						  &used_params, error);
+
+	JNIEnv *jenv = NULL;
         if (!sql)
 		goto out;
 
 	/* prepare @stmt using the C API, creates @ps */
 	GValue *pstmt_obj;
-	JNIEnv *jenv = NULL;
-	gboolean jni_detach;
+	gboolean jni_detach = FALSE;
 	jstring jsql;
 	
 	jenv = _gda_jdbc_get_jenv (&jni_detach, error);
@@ -1145,10 +1281,10 @@ gda_jdbc_provider_statement_prepare (GdaServerProvider *provider, GdaConnection
 			g_slist_free (param_ids);
 			goto out;
 		}
-		
+
 		GValue *jexec_res;
 		jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__declareParamTypes,
-						     pstmt_obj, NULL, NULL, error, (jlong)GPOINTER_TO_INT(cnc), jtypes);
+						     pstmt_obj, NULL, NULL, error, jni_cpointer_to_jlong (cnc), jtypes);
 		(*jenv)->DeleteLocalRef (jenv, jtypes);
 		g_free (ctypes);
 		
@@ -1783,7 +1919,7 @@ gda_jdbc_free_cnc_data (JdbcConnectionData *cdata)
 
 	if (cdata->jcnc_obj) {
 		/* force the connection to be closed */
-		JNIEnv *jenv;
+		JNIEnv *jenv = NULL;
 		gboolean jni_detach;
 		GError *error = NULL;
 
