@@ -2,6 +2,16 @@ import java.sql.*;
 import java.util.*;
 import java.io.*;
 
+/*
+ * Note:
+ * This provider invokes JNI in the following way: a C API calls some Java code through JNI, which in turn calls
+ * some C code as native method. To exchange pointers, the C pointers are converted to the "long" java type, which is mapped
+ * to the "jlong" C type which is always 64 bits long, refer to http://docs.oracle.com/javase/1.5.0/docs/guide/jni/spec/types.html
+ *
+ * In C code, when passing a C pointer to a method, it needs to be converted to a jlong, and the jni_cpointer_to_jlong()
+ * function must be used.
+ */
+
 /*
  * This class will be instantiated once for each GdaJdbcProvider created.
  */
@@ -46,6 +56,8 @@ class GdaJProvider {
 				res = driver.getClass().getName();
 			else
 				res = res + ":" + driver.getClass().getName();
+			if (false)
+				System.out.println ("FOUND DRIVER " + driver.getClass().getName());
 
 			// Properties list, for DSN spec creation.
 			if (false) {
@@ -244,7 +256,21 @@ class GdaJConnection {
 					catch (Exception e1) {
 						// nothing
 					}
-				}			       
+				}
+				else if (driver.contains ("sqlserver") ||
+					 driver.contains ("com.ashna.jturbo.driver.Driver") ||
+					 driver.contains ("com.inet.tds.TdsDriver")) {
+					try {
+						name = "sqlserverMeta";
+						Class<?> r = Class.forName (name);
+						java.lang.reflect.Constructor c =
+							r.getConstructor (new Class [] {Class.forName ("java.sql.Connection")});
+						jmeta = (GdaJMeta) c.newInstance (new Object [] {cnc});
+					}
+					catch (Exception e1) {
+						// nothing
+					}
+				}
 			}
 			if (jmeta == null)
 				jmeta = new GdaJMeta (cnc);
@@ -601,6 +627,7 @@ abstract class GdaJValue {
 	}
 
 	// Same as gda-jdbc-recordset.c::jdbc_type_to_g_type
+	// see http://docs.oracle.com/javase/6/docs/api/constant-values.html#java.sql.Types.ARRAY for reference
 	public static String jdbc_type_to_g_type (int type) {
 		switch (type) {
 		case java.sql.Types.VARCHAR:
@@ -608,7 +635,7 @@ abstract class GdaJValue {
 		case java.sql.Types.ARRAY:
 			return "GdaBinary";
 		case java.sql.Types.BIGINT:
-			return "int64";
+			return "gint64";
 		case java.sql.Types.BINARY:
 			return "GdaBinary";
 		case java.sql.Types.BIT:
@@ -629,28 +656,41 @@ abstract class GdaJValue {
 		case java.sql.Types.DISTINCT:
 			return "GdaBinary";
 		case java.sql.Types.DOUBLE:
-			return "double";
+			return "gdouble";
 		case java.sql.Types.FLOAT:
-			return "float";
+			return "gfloat";
 		case java.sql.Types.INTEGER:
-			return "int";
+			return "gint";
 		case java.sql.Types.JAVA_OBJECT:
+			return "GdaBinary";
+		case java.sql.Types.LONGNVARCHAR:
+			return "gchararray";
 		case java.sql.Types.LONGVARBINARY:
 			return "GdaBinary";
 		case java.sql.Types.LONGVARCHAR:
 			return "gchararray";
+		case java.sql.Types.NCHAR:
+			return "gchararray";
+		case java.sql.Types.NCLOB:
+			return "GdaBinary";
 		case java.sql.Types.NULL:
-			return null;
+			return "GdaNull";
 		case java.sql.Types.NUMERIC:
 			return "GdaNumeric";
+		case java.sql.Types.NVARCHAR:
+			return "gchararray";
 		case java.sql.Types.OTHER:
 			return "GdaBinary";
 		case java.sql.Types.REAL:
-			return "float";
+			return "gfloat";
 		case java.sql.Types.REF:
-			return "GdaBinary";
+			return "GdaBinary";	
+		case java.sql.Types.ROWID:
+			return "gchararray";
 		case java.sql.Types.SMALLINT:
-			return "GdaStort";
+			return "GdaShort";
+		case java.sql.Types.SQLXML:
+			return "gchararray";
 		case java.sql.Types.STRUCT:
 			return "GdaBinary";
 		case java.sql.Types.TIME:
