@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,7 @@
 #include "gda-ldap-util.h"
 #include <sqlite/virtual/gda-ldap-connection.h>
 #include <gda-util.h>
+#include <libgda/gda-debug-macros.h>
 
 static void
 ldap_attribute_free (LdapAttribute *lat)
@@ -402,13 +403,18 @@ gda_ldap_get_attr_info (LdapConnectionData *cdata, const gchar *attribute)
 	char *schema_attrs[] = {"attributeTypes", NULL};
 	
 	/* look for subschema */
+	if (! gda_ldap_ensure_bound (cdata, NULL))
+		return NULL;
+
 	res = ldap_search_ext_s (cdata->handle, "", LDAP_SCOPE_BASE,
 				 "(objectclass=*)",
 				 subschemasubentry, 0,
 				 NULL, NULL, NULL, 0,
 				 &msg);
-	if (res != LDAP_SUCCESS)
+	if (res != LDAP_SUCCESS) {
+		gda_ldap_may_unbind (cdata);
 		return NULL;
+	}
 
 	if ((entry = ldap_first_entry (cdata->handle, msg))) {
 		char *attr;
@@ -426,8 +432,10 @@ gda_ldap_get_attr_info (LdapConnectionData *cdata, const gchar *attribute)
 	}
 	ldap_msgfree (msg);
 
-	if (! subschema)
+	if (! subschema) {
+		gda_ldap_may_unbind (cdata);
 		return NULL;
+	}
 
 	/* look for attributeTypes */
 	res = ldap_search_ext_s (cdata->handle, subschema, LDAP_SCOPE_BASE,
@@ -436,8 +444,10 @@ gda_ldap_get_attr_info (LdapConnectionData *cdata, const gchar *attribute)
 				 NULL, NULL, NULL, 0,
 				 &msg);
 	g_free (subschema);
-	if (res != LDAP_SUCCESS)
+	if (res != LDAP_SUCCESS) {
+		gda_ldap_may_unbind (cdata);
 		return NULL;
+	}
 
 	if (cdata->attributes_cache_file)
 		string = g_string_new ("# Cache file. This file can safely be removed, in this case\n"
@@ -510,6 +520,7 @@ gda_ldap_get_attr_info (LdapConnectionData *cdata, const gchar *attribute)
 		g_string_free (string, TRUE);
 	}
 
+	gda_ldap_may_unbind (cdata);
 	retval = g_hash_table_lookup (cdata->attributes_hash, attribute);
 	return retval;
 }
@@ -556,13 +567,18 @@ gdaprov_ldap_get_class_info (GdaLdapConnection *cnc, const gchar *classname)
 	char *schema_attrs[] = {"objectClasses", NULL};
 	
 	/* look for subschema */
+	if (! gda_ldap_ensure_bound (cdata, NULL))
+		return NULL;
+
 	res = ldap_search_ext_s (cdata->handle, "", LDAP_SCOPE_BASE,
 				 "(objectclass=*)",
 				 subschemasubentry, 0,
 				 NULL, NULL, NULL, 0,
 				 &msg);
-	if (res != LDAP_SUCCESS)
+	if (res != LDAP_SUCCESS) {
+		gda_ldap_may_unbind (cdata);
 		return NULL;
+	}
 
 	if ((entry = ldap_first_entry (cdata->handle, msg))) {
 		char *attr;
@@ -580,8 +596,10 @@ gdaprov_ldap_get_class_info (GdaLdapConnection *cnc, const gchar *classname)
 	}
 	ldap_msgfree (msg);
 
-	if (! subschema)
+	if (! subschema) {
+		gda_ldap_may_unbind (cdata);
 		return NULL;
+	}
 
 	/* look for attributeTypes */
 	res = ldap_search_ext_s (cdata->handle, subschema, LDAP_SCOPE_BASE,
@@ -590,8 +608,10 @@ gdaprov_ldap_get_class_info (GdaLdapConnection *cnc, const gchar *classname)
 				 NULL, NULL, NULL, 0,
 				 &msg);
 	g_free (subschema);
-	if (res != LDAP_SUCCESS)
+	if (res != LDAP_SUCCESS) {
+		gda_ldap_may_unbind (cdata);
 		return NULL;
+	}
 
 	GHashTable *h_refs;
 	h_refs = g_hash_table_new_full (NULL, NULL, NULL, (GDestroyNotify) g_strfreev);
@@ -716,6 +736,7 @@ gdaprov_ldap_get_class_info (GdaLdapConnection *cnc, const gchar *classname)
 	g_hash_table_destroy (h_refs);
 
 	retval = g_hash_table_lookup (cdata->classes_hash, classname);
+	gda_ldap_may_unbind (cdata);
 	return retval;
 }
 
@@ -918,6 +939,90 @@ gda_ldap_attr_value_to_g_value (LdapConnectionData *cdata, GType type, BerValue
 	return value;
 }
 
+BerValue *
+gda_ldap_attr_g_value_to_value (LdapConnectionData *cdata, const GValue *cvalue)
+{
+	BerValue *bv;
+
+	if (!cvalue)
+		return NULL;
+
+	bv = g_new (struct berval, 1);
+
+	if (G_VALUE_TYPE (cvalue) == G_TYPE_STRING) {
+		const gchar *cstr;
+		cstr = g_value_get_string (cvalue);
+		bv->bv_val = g_strdup (cstr);
+		bv->bv_len = strlen (cstr);
+	}
+	else if (G_VALUE_TYPE (cvalue) == GDA_TYPE_TIMESTAMP) {
+		const GdaTimestamp *ts;
+		gchar *str;
+		ts = gda_value_get_timestamp (cvalue);
+		if (ts->fraction == 0) {
+			if (ts->timezone == GDA_TIMEZONE_INVALID)
+				str = g_strdup_printf ("%04d-%02d-%02dT%02d:%02d:%02d", ts->year, ts->month,
+						       ts->day, ts->hour, ts->minute, ts->second);
+			else {
+				str = g_strdup_printf ("%04d-%02d-%02dT%02d:%02d:%02d", ts->year, ts->month,
+						       ts->day, ts->hour, ts->minute, ts->second);
+				TO_IMPLEMENT;
+			}
+		}
+		else {
+			if (ts->timezone == GDA_TIMEZONE_INVALID)
+				str = g_strdup_printf ("%04d-%02d-%02dT%02d:%02d:%02d,%lu", ts->year, ts->month,
+						       ts->day, ts->hour, ts->minute, ts->second,
+						       ts->fraction);
+			else {
+				str = g_strdup_printf ("%04d-%02d-%02dT%02d:%02d:%02d,%lu", ts->year, ts->month,
+						       ts->day, ts->hour, ts->minute, ts->second,
+						       ts->fraction);
+				TO_IMPLEMENT;
+			}
+		}
+		bv->bv_val = str;
+		bv->bv_len = strlen (str);
+	}
+	else if (G_VALUE_TYPE (cvalue) == G_TYPE_DATE) {
+		GDate *date;
+		gchar *str;
+		date = (GDate*) g_value_get_boxed (cvalue);
+		str = g_strdup_printf ("%04d-%02d-%02d", g_date_get_year (date), g_date_get_month (date),
+				       g_date_get_day (date));
+		bv->bv_val = str;
+		bv->bv_len = strlen (str);
+	}
+	else if (G_VALUE_TYPE (cvalue) == GDA_TYPE_NULL) {
+		bv->bv_val = NULL;
+		bv->bv_len = 0;
+	}
+	else if (G_VALUE_TYPE (cvalue) == GDA_TYPE_BINARY) {
+		TO_IMPLEMENT;
+	}
+	else if (G_VALUE_TYPE (cvalue) == GDA_TYPE_BLOB) {
+		TO_IMPLEMENT;
+	}
+	else {
+		gchar *str;
+		str = gda_value_stringify (cvalue);
+		bv->bv_val = str;
+		bv->bv_len = strlen (str);
+	}
+	return bv;
+}
+
+/*
+ * Frees @bvalue, which MUST have been created using gda_ldap_attr_g_value_to_value()
+ */
+void
+gda_ldap_attr_value_free (LdapConnectionData *cdata, BerValue *bvalue)
+{
+	g_free (bvalue->bv_val);
+	g_free (bvalue);
+}
+
+
 /*
  * make sure we respect http://www.faqs.org/rfcs/rfc2253.html
  */
@@ -1065,6 +1170,9 @@ gda_ldap_parse_dn (const char *attr, gchar **out_userdn)
 	if (out_userdn)
 		*out_userdn = NULL;
 
+	if (!attr)
+		return FALSE;
+
 	/* decoding */
 	if (ldap_str2dn (attr, &tmpDN, LDAP_DN_FORMAT_LDAPV3) != LDAP_SUCCESS) {
 		if (ldap_str2dn (attr, &tmpDN, LDAP_DN_FORMAT_LDAPV2) != LDAP_SUCCESS) {
@@ -1112,6 +1220,10 @@ gdaprov_ldap_describe_entry (GdaLdapConnection *cnc, const gchar *dn, GError **e
         if (!cdata)
                 return NULL;
 
+
+	if (! gda_ldap_ensure_bound (cdata, error))
+		return NULL;
+
 	int res;
 	LDAPMessage *msg = NULL;
 	const gchar *real_dn;
@@ -1134,6 +1246,7 @@ gdaprov_ldap_describe_entry (GdaLdapConnection *cnc, const gchar *dn, GError **e
 		nb_entries = ldap_count_entries (cdata->handle, msg);
 		if (nb_entries == 0) {
 			ldap_msgfree (msg);
+			gda_ldap_may_unbind (cdata);
 			return NULL;
 		}
 		else if (nb_entries > 1) {
@@ -1141,6 +1254,7 @@ gdaprov_ldap_describe_entry (GdaLdapConnection *cnc, const gchar *dn, GError **e
 				     GDA_SERVER_PROVIDER_INTERNAL_ERROR,
 				     _("LDAP server returned more than one entry with DN '%s'"),
 				     real_dn);
+			gda_ldap_may_unbind (cdata);
 			return NULL;
 		}
 
@@ -1191,12 +1305,13 @@ gdaprov_ldap_describe_entry (GdaLdapConnection *cnc, const gchar *dn, GError **e
 			lentry->nb_attributes = array->len;
 			g_array_free (array, FALSE);
 		}
+		gda_ldap_may_unbind (cdata);
 		return lentry;
 	}
 	case LDAP_SERVER_DOWN: {
 		gint i;
 		for (i = 0; i < 5; i++) {
-			if (gda_ldap_silently_rebind (cdata))
+			if (gda_ldap_rebind (cdata, NULL))
 				goto retry;
 			g_usleep (G_USEC_PER_SEC * 2);
 		}
@@ -1207,6 +1322,7 @@ gdaprov_ldap_describe_entry (GdaLdapConnection *cnc, const gchar *dn, GError **e
 		ldap_get_option (cdata->handle, LDAP_OPT_ERROR_NUMBER, &ldap_errno);
 		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_OTHER_ERROR,
 			     "%s", ldap_err2string(ldap_errno));
+		gda_ldap_may_unbind (cdata);
 		return NULL;
 	}
 	}
@@ -1222,7 +1338,8 @@ entry_array_sort_func (gconstpointer a, gconstpointer b)
 }
 
 GdaLdapEntry **
-gdaprov_ldap_get_entry_children (GdaLdapConnection *cnc, const gchar *dn, gchar **attributes, GError **error)
+gdaprov_ldap_get_entry_children (GdaLdapConnection *cnc, const gchar *dn, gchar **attributes,
+				 GError **error)
 {
 	LdapConnectionData *cdata;
 	g_return_val_if_fail (GDA_IS_LDAP_CONNECTION (cnc), NULL);
@@ -1232,6 +1349,9 @@ gdaprov_ldap_get_entry_children (GdaLdapConnection *cnc, const gchar *dn, gchar
         if (!cdata)
                 return NULL;
 
+	if (! gda_ldap_ensure_bound (cdata, error))
+		return NULL;
+
 	int res;
 	LDAPMessage *msg = NULL;
  retry:
@@ -1327,6 +1447,7 @@ gdaprov_ldap_get_entry_children (GdaLdapConnection *cnc, const gchar *dn, gchar
 			g_array_append_val (children, lentry);
 		}
 		ldap_msgfree (msg);
+		gda_ldap_may_unbind (cdata);
 		if (children) {
 			g_array_sort (children, (GCompareFunc) entry_array_sort_func);
 			return (GdaLdapEntry**) g_array_free (children, FALSE);
@@ -1337,7 +1458,7 @@ gdaprov_ldap_get_entry_children (GdaLdapConnection *cnc, const gchar *dn, gchar
 	case LDAP_SERVER_DOWN: {
 		gint i;
 		for (i = 0; i < 5; i++) {
-			if (gda_ldap_silently_rebind (cdata))
+			if (gda_ldap_rebind (cdata, NULL))
 				goto retry;
 			g_usleep (G_USEC_PER_SEC * 2);
 		}
@@ -1348,6 +1469,7 @@ gdaprov_ldap_get_entry_children (GdaLdapConnection *cnc, const gchar *dn, gchar
 		ldap_get_option (cdata->handle, LDAP_OPT_ERROR_NUMBER, &ldap_errno);
 		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_OTHER_ERROR,
 			     "%s", ldap_err2string(ldap_errno));
+		gda_ldap_may_unbind (cdata);
 		return NULL;
 	}
 	}
@@ -1442,3 +1564,93 @@ gdaprov_ldap_get_base_dn (GdaLdapConnection *cnc)
 	else
 		return cdata->base_dn;
 }
+
+static gint
+def_cmp_func (GdaLdapAttributeDefinition *def1, GdaLdapAttributeDefinition *def2)
+{
+	return strcmp (def1->name, def2->name);
+}
+
+static GSList *
+handle_ldap_class (LdapConnectionData *cdata, GdaLdapClass *kl, GSList *retlist, GHashTable *hash)
+{
+	guint j;
+	/*g_print ("Class [%s] (%s)\n", kl->oid, kl->names[0]);*/
+	for (j = 0; j < kl->nb_req_attributes; j++) {
+		/*g_print ("  attr [%s] REQ\n", kl->req_attributes [j]);*/
+		GdaLdapAttributeDefinition *def;
+		LdapAttribute *latt;
+		latt = gda_ldap_get_attr_info (cdata, kl->req_attributes [j]);
+		def = g_hash_table_lookup (hash, kl->req_attributes [j]);
+		if (def)
+			def->required = TRUE;
+		else {
+			def = g_new0 (GdaLdapAttributeDefinition, 1);
+			def->name = g_strdup (kl->req_attributes [j]);
+			def->required = TRUE;
+			def->g_type = latt ? latt->type->gtype : G_TYPE_STRING;
+			g_hash_table_insert (hash, def->name, def);
+			retlist = g_slist_insert_sorted (retlist, def, (GCompareFunc) def_cmp_func);
+		}
+	}
+	for (j = 0; j < kl->nb_opt_attributes; j++) {
+		/*g_print ("  attr [%s] OPT\n", kl->opt_attributes [j]);*/
+		GdaLdapAttributeDefinition *def;
+		LdapAttribute *latt;
+		latt = gda_ldap_get_attr_info (cdata, kl->opt_attributes [j]);
+		def = g_hash_table_lookup (hash, kl->opt_attributes [j]);
+		if (!def) {
+			def = g_new0 (GdaLdapAttributeDefinition, 1);
+			def->name = g_strdup (kl->opt_attributes [j]);
+			def->required = FALSE;
+			def->g_type = latt ? latt->type->gtype : G_TYPE_STRING;
+			g_hash_table_insert (hash, def->name, def);
+			retlist = g_slist_insert_sorted (retlist, def, (GCompareFunc) def_cmp_func);
+		}
+	}
+
+	/* handle parents */
+	GSList *list;
+	for (list = kl->parents; list; list = list->next)
+		retlist = handle_ldap_class (cdata, (GdaLdapClass*) list->data, retlist, hash);
+
+	return retlist;
+}
+
+GSList *
+gdaprov_ldap_get_attributes_list (GdaLdapConnection *cnc, GdaLdapAttribute *object_class_attr)
+{
+	LdapConnectionData *cdata;
+	g_return_val_if_fail (GDA_IS_LDAP_CONNECTION (cnc), NULL);
+	g_return_val_if_fail (object_class_attr, NULL);
+
+	cdata = (LdapConnectionData*) gda_virtual_connection_internal_get_provider_data (GDA_VIRTUAL_CONNECTION (cnc));
+        if (!cdata)
+                return NULL;
+
+	guint i;
+	const gchar *tmp;
+	GHashTable *hash;
+	GSList *retlist = NULL;
+
+	hash = g_hash_table_new (g_str_hash, g_str_equal);
+	for (i = 0; i < object_class_attr->nb_values; i++) {
+		if (G_VALUE_TYPE (object_class_attr->values [i]) != G_TYPE_STRING) {
+			g_warning (_("Unexpected data type '%s' for objectClass attribute!"),
+				   gda_g_type_to_string (G_VALUE_TYPE (object_class_attr->values [i])));
+			continue;
+		}
+		tmp = g_value_get_string (object_class_attr->values [i]);
+
+		GdaLdapClass *kl;
+		kl = gdaprov_ldap_get_class_info (cnc, tmp);
+		if (!kl) {
+			/*g_warning (_("Can't get information about '%s' class"), tmp);*/
+			continue;
+		}
+		retlist = handle_ldap_class (cdata, kl, retlist, hash);
+	}
+	g_hash_table_destroy (hash);
+
+	return retlist;
+}
