@@ -31,6 +31,7 @@
 #include <libgda/gda-set.h>
 #include <libgda/gda-holder.h>
 #include "gda-oracle-util.h"
+#include <libgda/gda-debug-macros.h>
 
 /*
  * predefined statements' IDs
@@ -96,11 +97,10 @@ static gchar *internal_sql[] = {
  * global static values, and
  * predefined statements' GdaStatement, all initialized in _gda_oracle_provider_meta_init()
  */
-static GdaStatement **internal_stmt;
-static GdaSet        *i_set;
+static GMutex init_mutex;
+static GdaStatement **internal_stmt = NULL;
+static GdaSet        *i_set = NULL;
 static GdaSqlParser  *internal_parser = NULL;
-/* TO_ADD: other static values */
-
 
 /*
  * Meta initialization
@@ -108,26 +108,26 @@ static GdaSqlParser  *internal_parser = NULL;
 void
 _gda_oracle_provider_meta_init (GdaServerProvider *provider)
 {
-	static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
-	InternalStatementItem i;
+	g_mutex_lock (&init_mutex);
 
-	g_static_mutex_lock (&init_mutex);
+	if (!internal_stmt) {
+		InternalStatementItem i;
+		internal_parser = gda_server_provider_internal_get_parser (provider);
+		internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
+		for (i = I_STMT_CATALOG; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
+			internal_stmt[i] = gda_sql_parser_parse_string (internal_parser, internal_sql[i], NULL, NULL);
+			if (!internal_stmt[i])
+				g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+		}
 
-        internal_parser = gda_server_provider_internal_get_parser (provider);
-        internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
-        for (i = I_STMT_CATALOG; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
-                internal_stmt[i] = gda_sql_parser_parse_string (internal_parser, internal_sql[i], NULL, NULL);
-                if (!internal_stmt[i])
-                        g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
-        }
+		/* initialize static values here */
+		i_set = gda_set_new_inline (4, "cat", G_TYPE_STRING, "",
+					    "name", G_TYPE_STRING, "",
+					    "schema", G_TYPE_STRING, "",
+					    "name2", G_TYPE_STRING, "");
+	}
 
-	/* initialize static values here */
-	i_set = gda_set_new_inline (4, "cat", G_TYPE_STRING, "", 
-				    "name", G_TYPE_STRING, "",
-				    "schema", G_TYPE_STRING, "",
-				    "name2", G_TYPE_STRING, "");
-
-	g_static_mutex_unlock (&init_mutex);
+	g_mutex_unlock (&init_mutex);
 }
 
 gboolean
@@ -930,10 +930,12 @@ _gda_oracle_meta__columns (GdaServerProvider *prov, GdaConnection *cnc,
 
 	/* modify meta store with @model */
 	if (retval) {
+		/*
 		FILE *out;
 		out = fopen ("_columns", "w");
 		gda_data_model_dump (model, out);
 		fclose (out);
+		*/
 
 		gda_meta_store_set_identifiers_style (store, GDA_SQL_IDENTIFIERS_UPPER_CASE);
 		retval = gda_meta_store_modify_with_context (store, context, model, error);
