@@ -2507,12 +2507,12 @@ ora_remove_quotes (gchar *str)
         total = strlen (str);
         if (str[total-1] == delim) {
 		/* string is correctly terminated */
-		g_memmove (str, str+1, total-2);
+		memmove (str, str+1, total-2);
 		total -=2;
 	}
 	else {
 		/* string is _not_ correctly terminated */
-		g_memmove (str, str+1, total-1);
+		memmove (str, str+1, total-1);
 		total -=1;
 	}
         str[total] = 0;
@@ -2522,7 +2522,7 @@ ora_remove_quotes (gchar *str)
                 /* we accept the "''" as a synonym of "\'" */
                 if (*ptr == delim) {
                         if (*(ptr+1) == delim) {
-                                g_memmove (ptr+1, ptr+2, total - offset);
+                                memmove (ptr+1, ptr+2, total - offset);
                                 offset += 2;
                         }
                         else {
@@ -2532,13 +2532,13 @@ ora_remove_quotes (gchar *str)
                 }
                 if (*ptr == '\\') {
                         if (*(ptr+1) == '\\') {
-                                g_memmove (ptr+1, ptr+2, total - offset);
+                                memmove (ptr+1, ptr+2, total - offset);
                                 offset += 2;
                         }
                         else {
                                 if (*(ptr+1) == delim) {
                                         *ptr = delim;
-                                        g_memmove (ptr+1, ptr+2, total - offset);
+                                        memmove (ptr+1, ptr+2, total - offset);
                                         offset += 2;
                                 }
                                 else {
