@@ -5,8 +5,8 @@
  * Copyright (C) 2003 Gonzalo Paniagua Javier <gonzalo@src.gnome.org>
  * Copyright (C) 2003 Laurent Sansonetti <lrz@gnome.org>
  * Copyright (C) 2003 Steve Fosdick <fozzy@src.gnome.org>
- * Copyright (C) 2005 - 2009 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2005 lvaro Pea <alvaropg@telefonica.net>
+ * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2005 Álvaro Peña <alvaropg@telefonica.net>
  * Copyright (C) 2007 Murray Cumming <murrayc@murrayc-desktop>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  *
@@ -116,7 +116,7 @@ gda_oracle_recordset_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaOracleRecordsetClass),
 			(GBaseInitFunc) NULL,
@@ -129,10 +129,10 @@ gda_oracle_recordset_get_type (void)
 			(GInstanceInitFunc) gda_oracle_recordset_init,
 			NULL
 		};
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_DATA_SELECT, "GdaOracleRecordset", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 
 	return type;
@@ -148,6 +148,8 @@ ora_def_callback (GdaOracleValue *ora_value,
 		  dvoid **indpp,
 		  ub2 **rcodep)
 {
+	*piecep = OCI_ONE_PIECE;
+
 	if (!ora_value->value) {
 		/* 1st chunk */
 		ora_value->defined_size = 0;
@@ -395,6 +397,9 @@ gda_oracle_recordset_new (GdaConnection *cnc, GdaOraclePStmt *ps, GdaSet *exec_p
 			case SQLT_BIN:
 				use_callback = TRUE;
 				break;
+			default:
+				use_callback = TRUE;
+				break;
 			}
 			
 			if (_GDA_PSTMT (ps)->types [i] != GDA_TYPE_NULL)
