@@ -38,6 +38,7 @@
 #include "gda-capi-recordset.h"
 #include "gda-capi-ddl.h"
 #include "gda-capi-meta.h"
+#include <libgda/gda-debug-macros.h>
 #define _GDA_PSTMT(x) ((GdaPStmt*)(x))
 
 /*
@@ -144,7 +145,8 @@ static void gda_capi_free_cnc_data (CapiConnectionData *cdata);
  * TO_ADD: any prepared statement to be used internally by the provider should be
  *         declared here, as constants and as SQL statements
  */
-static GdaStatement **internal_stmt;
+static GMutex init_mutex;
+static GdaStatement **internal_stmt = NULL;
 
 typedef enum {
 	INTERNAL_STMT1
@@ -262,21 +264,27 @@ gda_capi_provider_class_init (GdaCapiProviderClass *klass)
 static void
 gda_capi_provider_init (GdaCapiProvider *capi_prv, G_GNUC_UNUSED GdaCapiProviderClass *klass)
 {
-	InternalStatementItem i;
-	GdaSqlParser *parser;
+	g_mutex_lock (&init_mutex);
 
-	parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) capi_prv);
-	internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
-	for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
-		internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
-		if (!internal_stmt[i]) 
-			g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+	if (!internal_stmt) {
+		InternalStatementItem i;
+		GdaSqlParser *parser;
+
+		parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) capi_prv);
+		internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
+		for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
+			internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
+			if (!internal_stmt[i])
+				g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+		}
 	}
 
 	/* meta data init */
 	_gda_capi_provider_meta_init ((GdaServerProvider*) capi_prv);
 
 	/* TO_ADD: any other provider's init should be added here */
+
+	g_mutex_unlock (&init_mutex);
 }
 
 GType
@@ -285,7 +293,7 @@ gda_capi_provider_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static GTypeInfo info = {
 			sizeof (GdaCapiProviderClass),
 			(GBaseInitFunc) NULL,
@@ -297,10 +305,10 @@ gda_capi_provider_get_type (void)
 			(GInstanceInitFunc) gda_capi_provider_init,
 			0
 		};
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_SERVER_PROVIDER, "GdaCapiProvider", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 
 	return type;
@@ -817,7 +825,7 @@ gda_capi_provider_get_data_handler (GdaServerProvider *provider, GdaConnection *
 		dh = NULL;
 	}
 	else
-		dh = gda_server_provider_get_data_handler_default (provider, cnc, type, dbms_type);
+		dh = gda_server_provider_handler_use_default (provider, type);
 
 	return dh;
 }
@@ -1231,6 +1239,11 @@ gda_capi_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 			}
 		}
 		else {
+			/* usually the way to bind parameters is different depending on the type of @value.
+			 * Also, if the database engine does not support storing timezone information for time and
+			 * timestamp values, then before binding, the value must be converted to GMT using
+			 * gda_time_change_timezone (xxx, 0) or gda_timestamp_change_timezone (xxx, 0)
+			 */
 			TO_IMPLEMENT;
 		}
 	}
