@@ -26,6 +26,7 @@
 #include <tests/gda-ddl-creator.h>
 #include <glib/gstdio.h>
 #include "../test-cnc-utils.h"
+#include "../test-errors.h"
 
 #define fail(x) g_warning (x)
 #define fail_if(x,y) if (x) g_warning (y)
@@ -450,7 +451,7 @@ test3 (GdaConnection *cnc)
 
 	/****/
 	gda_value_set_from_string ((value = gda_value_new (GDA_TYPE_TIMESTAMP)), 
-				   "2009-11-30 11:22:33", GDA_TYPE_TIMESTAMP);
+				   "2009-11-30 11:22:33+0", GDA_TYPE_TIMESTAMP);
 	if (! check_set_value_at (model, 2, 1, value, cnc, stmt, NULL)) {
 		nfailed ++;
 		goto out;
@@ -878,7 +879,7 @@ test7 (GdaConnection *cnc)
 	}
 
 	gda_value_set_from_string ((value = gda_value_new (GDA_TYPE_TIMESTAMP)), 
-				   "2004-03-22 11:22:44", GDA_TYPE_TIMESTAMP);
+				   "2004-03-22 11:22:44+0", GDA_TYPE_TIMESTAMP);
 	if (! check_set_value_at (model, 2, 1, value, cnc, stmt, params)) {
 		nfailed ++;
 		goto out;
@@ -1017,7 +1018,7 @@ test9 (GdaConnection *cnc)
 	monitor_model_signals (model);
 	g_value_set_string ((value = gda_value_new (G_TYPE_STRING)), "UK");
 	if (! check_set_value_at_ext (model, 4, 1, value, cnc, stmt, params, &error)) {
-		if (error && (error->domain == 0) && (error->code == -1)) {
+		if (error && (error->domain == TEST_ERROR) && (error->code == TEST_ERROR_DIFFERENCES)) {
 #ifdef CHECK_EXTRA_INFO
 			g_print ("This error was expected (modified row would not have been in the SELECT)\n");
 #endif	
@@ -1452,7 +1453,7 @@ test13 (GdaConnection *cnc)
 
 	/****/
 	gda_value_set_from_string ((value = gda_value_new (GDA_TYPE_TIMESTAMP)), 
-				   "2009-11-30 11:22:33", GDA_TYPE_TIMESTAMP);
+				   "2009-11-30 11:22:33+0", GDA_TYPE_TIMESTAMP);
 	if (! check_set_value_at (model, 1, 1, value, cnc, stmt, NULL)) {
 		nfailed ++;
 		goto out;
@@ -1547,7 +1548,7 @@ test14 (GdaConnection *cnc)
 
 	/****/
 	gda_value_set_from_string ((value = gda_value_new (GDA_TYPE_TIMESTAMP)), 
-				   "2019-11-30 11:22:33", GDA_TYPE_TIMESTAMP);
+				   "2019-11-30 11:22:33+0", GDA_TYPE_TIMESTAMP);
 	if (! check_set_value_at (model, 1, 1, value, cnc, stmt, NULL)) {
 		nfailed ++;
 		goto out;
@@ -1984,7 +1985,7 @@ check_set_value_at_ext (GdaDataModel *model, gint col, gint row,
 			gda_data_model_dump (model, stdout);
 			gda_data_model_dump (rerun, stdout);
 			if (error) {
-				g_set_error (error, 0, -1,
+				g_set_error (error, TEST_ERROR, TEST_ERROR_DIFFERENCES,
 					     "%s", "There are some differences when re-running the SELECT statement...");
 			}
 		}
@@ -2340,7 +2341,7 @@ compare_data_models (GdaDataModel *model1, GdaDataModel *model2, GError **error)
                 g_print ("Model2 is:\n");
                 gda_data_model_dump (model2, stdout);
 #endif
-		g_set_error (&lerror, 0, 0,
+		g_set_error (&lerror, TEST_ERROR, TEST_ERROR_GENERIC,
 			     "%s", "There are some differences when comparing data models...");
                 goto onerror;
         }
