@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2008 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,7 +42,10 @@ TestFunc tests[] = {
 int 
 main (int argc, char** argv)
 {
+#if GLIB_CHECK_VERSION(2,36,0)
+#else
 	g_type_init ();
+#endif
 	gda_init ();
 
 	gint failures = 0;
