@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 - 2013 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2012 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,6 +24,8 @@
 #include <sql-parser/gda-sql-parser.h>
 #include <sql-parser/gda-sql-statement.h>
 #include "../test-cnc-utils.h"
+#include "../test-errors.h"
+
 
 #define CHECK_EXTRA_INFO
 /*#undef CHECK_EXTRA_INFO*/
@@ -38,7 +42,7 @@ gboolean         fork_tests = TRUE;
  */
 
 int
-prov_test_common_setup ()
+prov_test_common_setup (void)
 {
 	int number_failed = 0;
 	GError *error = NULL;
@@ -50,7 +54,7 @@ prov_test_common_setup ()
 	cnc = test_cnc_setup_connection (pinfo->id, "testcheckdb", &error);
 	if (!cnc) {
 		if (error) {
-			if (error->domain != 0) {
+			if (error->domain != TEST_ERROR) {
 				gchar *str = g_strdup_printf ("Could not setup connection: %s", 
 							      error->message ? error->message : "No detail");
 				g_warning ("%s", str);
@@ -79,6 +83,19 @@ prov_test_common_setup ()
 	return number_failed;
 }
 
+GdaConnection *
+prov_test_common_create_extra_connection (void)
+{
+	GdaConnection *cnc;
+	GError *lerror = NULL;
+	cnc = test_cnc_open_connection (pinfo->id, "testcheckdb", &lerror);
+	if (!cnc) {
+		g_print ("Error setting up connection: %s\n", lerror && lerror->message ? lerror->message : "No detail");
+		g_clear_error (&lerror);
+	}
+	return cnc;
+}
+
 
 /*
  *
@@ -86,7 +103,7 @@ prov_test_common_setup ()
  *
  */
 int
-prov_test_common_clean ()
+prov_test_common_clean (void)
 {
 	int number_failed = 0;
 
@@ -107,7 +124,7 @@ prov_test_common_clean ()
  */
 
 int
-prov_test_common_check_meta ()
+prov_test_common_check_meta (void)
 {
 	int number_failed = 0;
 	GSList *tables = NULL, *list;
@@ -188,7 +205,35 @@ prov_test_common_check_meta ()
 		number_failed++;
 		goto theend;
 	}
-
+	/* Update meta store by context */
+	GdaMetaContext *ctx;
+	ctx = gda_meta_context_new ();
+	gchar *meta_tables[] = {"_tables", "_attributes", "_information_schema_catalog_name",
+						"_schemata", "_builtin_data_types", "_udt", "_udt_columns",
+						"_enums", "_element_types", "_domains", "_views", "_collations",
+						"_character_sets", "_routines", "_triggers", "_columns",
+						"_table_constraints", "_referential_constraints",
+						"_key_column_usage", "__declared_fk", "_check_column_usage",
+						"_view_column_usage", "_domain_constraints", "_parameters",
+						"_routine_columns", "_table_indexes", "_index_column_usage",
+						NULL};
+	for (i = 0; meta_tables[i]; i++) {
+		gda_meta_context_set_table (ctx, meta_tables[i]);
+#ifdef CHECK_EXTRA_INFO
+		g_print ("Updating the meta store for table '%s'\n", meta_tables[i]);
+#endif
+		if (! gda_connection_update_meta_store (cnc, ctx, &gerror)) {
+#ifdef CHECK_EXTRA_INFO
+			g_warning ("Can't update meta store (on table %s): %s\n",
+				   meta_tables[i], gerror && gerror->message ? gerror->message : "???");
+#endif
+			g_error_free (gerror);
+			number_failed++;
+			goto theend;
+		}
+	}
+	gda_meta_context_free (ctx);
+	
 	for (i = 0, list = tables; list; i++, list = list->next) {
 		GdaDataModel *model;
 		gchar *tmp;
@@ -280,7 +325,7 @@ prov_test_common_check_meta_identifiers (gboolean case_sensitive, gboolean updat
         operation = gda_server_provider_create_operation (provider, cnc,
 							  GDA_SERVER_OPERATION_DROP_TABLE, NULL, &error);
         g_assert (operation);
-        gda_server_operation_set_value_at (operation, table_name, NULL, "/TABLE_DESC_P/TABLE_NAME");
+        gda_server_operation_set_value_at_path (operation, table_name, "/TABLE_DESC_P/TABLE_NAME", NULL);
         gda_server_provider_perform_operation (provider, cnc, operation, NULL);
 	g_object_unref (operation);
 
@@ -396,9 +441,9 @@ prov_test_common_check_meta_identifiers (gboolean case_sensitive, gboolean updat
 	operation = gda_server_provider_create_operation (provider, cnc,
 							  GDA_SERVER_OPERATION_ADD_COLUMN, NULL, &error);
         g_assert (operation);
-        gda_server_operation_set_value_at (operation, table_name, NULL, "/COLUMN_DEF_P/TABLE_NAME");
-        gda_server_operation_set_value_at (operation, field_name, NULL, "/COLUMN_DEF_P/COLUMN_NAME");
-        gda_server_operation_set_value_at (operation, "int", NULL, "/COLUMN_DEF_P/COLUMN_TYPE");
+        gda_server_operation_set_value_at_path (operation, table_name, "/COLUMN_DEF_P/TABLE_NAME", NULL);
+        gda_server_operation_set_value_at (operation, field_name, NULL, "/COLUMN_DEF_P/COLUMN_NAME", NULL);
+        gda_server_operation_set_value_at (operation, "int", NULL, "/COLUMN_DEF_P/COLUMN_TYPE", NULL);
         if (! gda_server_provider_perform_operation (provider, cnc, operation, &error)) {
 #ifdef CHECK_EXTRA_INFO
                 g_warning ("perform_operation(ADD_COLUMN) failed: %s\n", error && error->message ? 
@@ -497,7 +542,7 @@ prov_test_common_check_meta_identifiers (gboolean case_sensitive, gboolean updat
  *
  */
 int
-prov_test_common_load_data ()
+prov_test_common_load_data (void)
 {
 	int number_failed = 0;
 
@@ -523,7 +568,7 @@ prov_test_common_load_data ()
  *
  */
 int
-prov_test_common_check_cursor_models ()
+prov_test_common_check_cursor_models (void)
 {
 	int number_failed = 0;
 
@@ -552,7 +597,7 @@ prov_test_common_check_cursor_models ()
  *
  */
 int 
-prov_test_common_check_data_select ()
+prov_test_common_check_data_select (void)
 {
 	GdaSqlParser *parser = NULL;
 	GdaStatement *stmt = NULL;
@@ -580,7 +625,7 @@ prov_test_common_check_data_select ()
 		goto out;
 	}
 	if (remain) {
-		g_set_error (&error, 0, 0,
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_PARSING,
 			     "Parsing error, remains: %s", remain);
 		number_failed ++;
 		goto out;
@@ -600,7 +645,7 @@ prov_test_common_check_data_select ()
 	}
 
 	if (gda_data_model_get_n_rows (model) != 0) {
-		g_set_error (&error, 0, 0,
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
 			     "Data model reports %d rows when 0 expected", gda_data_model_get_n_rows (model));
 		number_failed ++;
 		goto out;
@@ -619,7 +664,7 @@ prov_test_common_check_data_select ()
         }
 
 	if (gda_data_model_get_n_rows (model) != 9) {
-		g_set_error (&error, 0, 0,
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
 			     "Data model reports %d rows when 9 expected", gda_data_model_get_n_rows (model));
 		number_failed ++;
 		goto out;
@@ -628,7 +673,7 @@ prov_test_common_check_data_select ()
 	/* check the columns haven't changed */
 	ncols = gda_data_model_get_n_columns (model);
 	if (i != ncols) {
-		g_set_error (&error, 0, 0,
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
 			     "Number of columns has changed from %d to %d\n", i, ncols);
 		number_failed ++;
 		goto out;
@@ -636,7 +681,7 @@ prov_test_common_check_data_select ()
 
 	for (i = 0; i < ncols; i++) {
 		if (gda_data_model_describe_column (model, i) != g_slist_nth_data (columns, i)) {
-			g_set_error (&error, 0, 0,
+			g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
 				     "GdaColumn %d has changed from %p to %p\n", i, 
 				     g_slist_nth_data (columns, i),
 				     gda_data_model_describe_column (model, i));
@@ -664,3 +709,321 @@ prov_test_common_check_data_select ()
 
 	return number_failed;
 }
+
+
+/*
+ * Check that timezones are handled correctly when storing and retreiving timestamps
+ */
+static gboolean
+timestamp_equal (const GValue *cv1, const GValue *cv2)
+{
+	g_assert (G_VALUE_TYPE (cv1) == GDA_TYPE_TIMESTAMP);
+	g_assert (G_VALUE_TYPE (cv2) == GDA_TYPE_TIMESTAMP);
+	const GdaTimestamp *ts1, *ts2;
+	ts1 = gda_value_get_timestamp (cv1);
+	ts2 = gda_value_get_timestamp (cv2);
+	if (ts1->timezone == ts2->timezone)
+		return gda_value_differ (cv1, cv2) ? FALSE : TRUE;
+
+	GdaTimestamp *ts;
+	ts = gda_timestamp_copy ((GdaTimestamp*) ts1);
+	gda_timestamp_change_timezone (ts, ts2->timezone);
+	gboolean res;
+	res = memcmp (ts2, ts, sizeof (GdaTimestamp)) ? FALSE : TRUE;
+	gda_timestamp_free (ts);
+	return res;
+}
+
+int
+prov_test_common_check_timestamp (void)
+{
+	GdaSqlParser *parser = NULL;
+	GdaStatement *stmt = NULL;
+	GdaSet *params = NULL;
+	GError *error = NULL;
+	int number_failed = 0;
+	GdaDataModel *model = NULL;
+
+#ifdef CHECK_EXTRA_INFO
+	g_print ("\n============= %s() =============\n", __FUNCTION__);
+#endif
+
+	parser = gda_connection_create_parser (cnc);
+	if (!parser)
+		parser = gda_sql_parser_new ();
+
+	GValue *tso;
+	tso = gda_value_new_timestamp_from_timet (time (NULL));
+
+	/* insert timestamp */
+	stmt = gda_sql_parser_parse_string (parser, "INSERT INTO tstest (ts) VALUES (##ts::timestamp)", NULL, &error);
+	if (!stmt ||
+	    ! gda_statement_get_parameters (stmt, &params, &error) ||
+	    ! gda_set_set_holder_value (params, &error, "ts", gda_value_get_timestamp (tso)) ||
+	    (gda_connection_statement_execute_non_select (cnc, stmt, params, NULL, &error) == -1)) {
+		number_failed ++;
+		goto out;
+	}
+
+	g_print ("Inserted TS %s\n", gda_value_stringify (tso));
+
+	/* retreive timestamp */
+	stmt = gda_sql_parser_parse_string (parser, "SELECT ts FROM tstest", NULL, &error);
+	if (!stmt) {
+		number_failed ++;
+		goto out;
+	}
+
+	model = gda_connection_statement_execute_select (cnc, stmt, NULL, &error);
+	if (!model) {
+		number_failed ++;
+		goto out;
+	}
+	gda_data_model_dump (model, NULL);
+	if (gda_data_model_get_n_rows (model) != 1) {
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
+			     "Data model should have exactly 1 row");
+		number_failed ++;
+		goto out;
+	}
+
+	const GValue *cvalue;
+	cvalue = gda_data_model_get_typed_value_at (model, 0, 0, GDA_TYPE_TIMESTAMP, FALSE, &error);
+	if (!cvalue) {
+		number_failed ++;
+		goto out;
+	}
+	if (! timestamp_equal (tso, cvalue)) {
+		gchar *tmpg, *tmpe;
+		tmpg = gda_value_stringify (cvalue);
+		tmpe = gda_value_stringify (tso);
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
+			     "Retreived time stamp differs from expected: got '%s' and expected '%s'", tmpg, tmpe);
+		g_free (tmpg);
+		g_free (tmpe);
+		number_failed ++;
+		goto out;
+	}
+
+	/* check that data handler is correctly configured: compare the same timestamp rendered by a data handler for
+	 * timestamps with the date rendered as a string by the server (by appending a string to the timestamp field) */
+	GdaDataHandler *dh;
+	dh = gda_server_provider_get_data_handler_g_type (gda_connection_get_provider (cnc), cnc, GDA_TYPE_TIMESTAMP);
+	gchar *str;
+	str = gda_data_handler_get_str_from_value (dh, cvalue);
+	g_object_unref (model);
+
+	stmt = gda_sql_parser_parse_string (parser, "SELECT ts || 'asstring' FROM tstest", NULL, &error); /* retreive timestamp as string */
+	if (!stmt) {
+		g_free (str);
+		number_failed ++;
+		goto out;
+	}
+
+	model = gda_connection_statement_execute_select (cnc, stmt, NULL, &error);
+	if (!model) {
+		g_free (str);
+		number_failed ++;
+		goto out;
+	}
+	gda_data_model_dump (model, NULL);
+	if (gda_data_model_get_n_rows (model) != 1) {
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
+			     "Data model should have exactly 1 row");
+		g_free (str);
+		number_failed ++;
+		goto out;
+	}
+	cvalue = gda_data_model_get_typed_value_at (model, 0, 0, G_TYPE_STRING, FALSE, &error);
+	if (!cvalue) {
+		g_free (str);
+		number_failed ++;
+		goto out;
+	}	
+	if (strncmp (str, g_value_get_string (cvalue), 10)) { /* only compare date parts */
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
+			     "Returned GdaDataHandler returned wrong result: '%s' and expected '%s'", str, g_value_get_string (cvalue));
+		g_free (str);
+		number_failed ++;
+		goto out;
+	}
+
+out:
+	if (stmt)
+		g_object_unref (stmt);
+	if (params)
+		g_object_unref (params);
+	if (model)
+		g_object_unref (model);
+	g_object_unref (parser);
+
+#ifdef CHECK_EXTRA_INFO
+	g_print ("Timestamp test resulted in %d error(s)\n", number_failed);
+	if (number_failed != 0) 
+		g_print ("error: %s\n", error && error->message ? error->message : "No detail");
+	if (error)
+		g_error_free (error);
+#endif
+
+	return number_failed;
+}
+
+static GValue *
+value_new_date_from_timet (time_t val)
+{
+	GValue *value;
+	GDate *date;
+	date = g_date_new ();
+	g_date_set_time_t (date, val);
+
+	value = gda_value_new (G_TYPE_DATE);
+	g_value_set_boxed (value, date);
+	g_date_free (date);
+
+        return value;
+}
+
+static gboolean
+date_equal (const GValue *cv1, const GValue *cv2)
+{
+	g_assert (G_VALUE_TYPE (cv1) == G_TYPE_DATE);
+	g_assert (G_VALUE_TYPE (cv2) == G_TYPE_DATE);
+	const GDate *ts1, *ts2;
+	ts1 = (GDate*) g_value_get_boxed (cv1);
+	ts2 = (GDate*) g_value_get_boxed (cv2);
+	return g_date_compare (ts1, ts2) ? FALSE : TRUE;
+}
+
+int
+prov_test_common_check_date (void)
+{
+	GdaSqlParser *parser = NULL;
+	GdaStatement *stmt = NULL;
+	GdaSet *params = NULL;
+	GError *error = NULL;
+	int number_failed = 0;
+	GdaDataModel *model = NULL;
+
+#ifdef CHECK_EXTRA_INFO
+	g_print ("\n============= %s() =============\n", __FUNCTION__);
+#endif
+
+	parser = gda_connection_create_parser (cnc);
+	if (!parser)
+		parser = gda_sql_parser_new ();
+
+	GValue *tso;
+	tso = value_new_date_from_timet (time (NULL));
+
+	/* insert date */
+	stmt = gda_sql_parser_parse_string (parser, "INSERT INTO datetest (thedate) VALUES (##thedate::date)", NULL, &error);
+	if (!stmt ||
+	    ! gda_statement_get_parameters (stmt, &params, &error) ||
+	    ! gda_set_set_holder_value (params, &error, "thedate", (GDate*) g_value_get_boxed (tso)) ||
+	    (gda_connection_statement_execute_non_select (cnc, stmt, params, NULL, &error) == -1)) {
+		number_failed ++;
+		goto out;
+	}
+
+	g_print ("Inserted date %s\n", gda_value_stringify (tso));
+
+	/* retreive date */
+	stmt = gda_sql_parser_parse_string (parser, "SELECT thedate FROM datetest", NULL, &error);
+	if (!stmt) {
+		number_failed ++;
+		goto out;
+	}
+
+	model = gda_connection_statement_execute_select (cnc, stmt, NULL, &error);
+	if (!model) {
+		number_failed ++;
+		goto out;
+	}
+	gda_data_model_dump (model, NULL);
+	if (gda_data_model_get_n_rows (model) != 1) {
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
+			     "Data model should have exactly 1 row");
+		number_failed ++;
+		goto out;
+	}
+
+	const GValue *cvalue;
+	cvalue = gda_data_model_get_typed_value_at (model, 0, 0, G_TYPE_DATE, FALSE, &error);
+	if (!cvalue) {
+		number_failed ++;
+		goto out;
+	}
+	if (! date_equal (tso, cvalue)) {
+		gchar *tmpg, *tmpe;
+		tmpg = gda_value_stringify (cvalue);
+		tmpe = gda_value_stringify (tso);
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
+			     "Retreived date differs from expected: got '%s' and expected '%s'", tmpg, tmpe);
+		g_free (tmpg);
+		g_free (tmpe);
+		number_failed ++;
+		goto out;
+	}
+
+	/* check that data handler is correctly configured: compare the same timestamp rendered by a data handler for
+	 * timestamps with the date rendered as a string by the server (by appending a string to the timestamp field) */
+	GdaDataHandler *dh;
+	dh = gda_server_provider_get_data_handler_g_type (gda_connection_get_provider (cnc), cnc, G_TYPE_DATE);
+	gchar *str;
+	str = gda_data_handler_get_str_from_value (dh, cvalue);
+	g_object_unref (model);
+
+	stmt = gda_sql_parser_parse_string (parser, "SELECT thedate || 'asstring' FROM datetest", NULL, &error); /* retreive date as string */
+	if (!stmt) {
+		g_free (str);
+		number_failed ++;
+		goto out;
+	}
+
+	model = gda_connection_statement_execute_select (cnc, stmt, NULL, &error);
+	if (!model) {
+		g_free (str);
+		number_failed ++;
+		goto out;
+	}
+	gda_data_model_dump (model, NULL);
+	if (gda_data_model_get_n_rows (model) != 1) {
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
+			     "Data model should have exactly 1 row");
+		g_free (str);
+		number_failed ++;
+		goto out;
+	}
+	cvalue = gda_data_model_get_typed_value_at (model, 0, 0, G_TYPE_STRING, FALSE, &error);
+	if (!cvalue) {
+		g_free (str);
+		number_failed ++;
+		goto out;
+	}	
+	if (strncmp (str, g_value_get_string (cvalue), 10)) { /* only compare date parts */
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
+			     "Returned GdaDataHandler returned wrong result: '%s' and expected '%s'", str, g_value_get_string (cvalue));
+		g_free (str);
+		number_failed ++;
+		goto out;
+	}
+
+out:
+	if (stmt)
+		g_object_unref (stmt);
+	if (params)
+		g_object_unref (params);
+	if (model)
+		g_object_unref (model);
+	g_object_unref (parser);
+
+#ifdef CHECK_EXTRA_INFO
+	g_print ("Date test resulted in %d error(s)\n", number_failed);
+	if (number_failed != 0) 
+		g_print ("error: %s\n", error && error->message ? error->message : "No detail");
+	if (error)
+		g_error_free (error);
+#endif
+
+	return number_failed;
+}
