@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,7 +40,10 @@ TestFunc tests[] = {
 int 
 main (int argc, char** argv)
 {
+#if GLIB_CHECK_VERSION(2,36,0)
+#else
 	g_type_init ();
+#endif
 	gda_init ();
 
 	guint failures = 0;
@@ -162,7 +166,7 @@ test2 (GError **error)
 	
 	fname = g_build_filename (ROOT_DIR, "tests", "parser", "testdata.xml", NULL);
 	if (! g_file_test (fname, G_FILE_TEST_EXISTS)) {
-                g_set_error (error, 0, 0, "File '%s' does not exist\n", fname);
+                g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "File '%s' does not exist\n", fname);
 		return FALSE;
         }
 	doc = xmlParseFile (fname);
@@ -241,7 +245,7 @@ test2 (GError **error)
 			gda_sql_statement_free (sqlst);
 			
 			if (strcmp (ser1, ser2)) {
-				g_set_error (error, 0, 0,
+				g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC,
 					     "Statement failed, ID: %s\nSQL: %s\nSER1: %s\nSER2 :%s", 
 					     id, rsql, ser1, ser2);
 				g_free (ser1);
