@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,9 +35,9 @@ typedef struct {
 					 * to another GdaHolder */
 } ToolsFavoriteAction;
 
-GSList             *tools_favorites_get_actions  (ToolsFavorites *bfav, BrowserConnection *bcnc, GdaSet *set);
-void                tools_favorites_free_action  (ToolsFavoriteAction *action);
-void                tools_favorites_free_actions_list (GSList *actions_list);
+GSList             *gda_tools_favorites_get_actions  (ToolsFavorites *bfav, BrowserConnection *bcnc, GdaSet *set);
+void                gda_tools_favorites_free_action  (ToolsFavoriteAction *action);
+void                gda_tools_favorites_free_actions_list (GSList *actions_list);
 
 G_END_DECLS
 
