@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,7 +28,7 @@
 #include "../dnd.h"
 #include "../support.h"
 #include "marshal.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include <gdk/gdkkeysyms.h>
 #include <libgda-ui/internal/popup-container.h>
 
@@ -194,7 +195,7 @@ key_press_event_cb (GtkTreeView *treeview, GdkEventKey *event, DataFavoriteSelec
 			gtk_tree_model_get (model, &iter,
 					    COLUMN_ID, &(fav.id), -1);
 			bfav = browser_connection_get_favorites (tsel->priv->bcnc);
-			if (!tools_favorites_delete (bfav, 0, &fav, NULL)) {
+			if (!gda_tools_favorites_delete (bfav, 0, &fav, NULL)) {
 				browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*)tsel),
 						    _("Could not remove favorite: %s"),
 						    lerror && lerror->message ? lerror->message : _("No detail"));
@@ -240,7 +241,7 @@ prop_save_timeout (DataFavoriteSelector *tsel)
 
 	memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
 	fav.id = tsel->priv->properties_id;
-	fav.type = TOOLS_FAVORITES_DATA_MANAGERS;
+	fav.type = GDA_TOOLS_FAVORITES_DATA_MANAGERS;
 	fav.name = (gchar*) gtk_entry_get_text (GTK_ENTRY (tsel->priv->properties_name));
 	fav.descr = NULL;
 
@@ -252,7 +253,7 @@ prop_save_timeout (DataFavoriteSelector *tsel)
 	fav.contents = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
 
 	bfav = browser_connection_get_favorites (tsel->priv->bcnc);
-	if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_DATA_MANAGERS, tsel->priv->properties_position, &error)) {
+	if (! gda_tools_favorites_add (bfav, 0, &fav, ORDER_KEY_DATA_MANAGERS, tsel->priv->properties_position, &error)) {
 		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tsel),
 				    _("Could not add favorite: %s"),
 				    error && error->message ? error->message : _("No detail"));
@@ -277,7 +278,7 @@ static void
 properties_activated_cb (GtkMenuItem *mitem, DataFavoriteSelector *tsel)
 {
 	if (! tsel->priv->popup_properties) {
-		GtkWidget *pcont, *vbox, *hbox, *label, *entry, *text, *table;
+		GtkWidget *pcont, *vbox, *hbox, *label, *entry, *text, *grid;
 		gchar *str;
 		
 		pcont = popup_container_new (GTK_WIDGET (mitem));
@@ -296,25 +297,25 @@ properties_activated_cb (GtkMenuItem *mitem, DataFavoriteSelector *tsel)
 		label = gtk_label_new ("      ");
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 		
-		table = gtk_table_new (2, 2, FALSE);
-		gtk_box_pack_start (GTK_BOX (hbox), table, TRUE, TRUE, 0);
+		grid = gtk_grid_new ();
+		gtk_box_pack_start (GTK_BOX (hbox), grid, TRUE, TRUE, 0);
 		
 		label = gtk_label_new ("");
 		str = g_strdup_printf ("<b>%s:</b>", _("Name"));
 		gtk_label_set_markup (GTK_LABEL (label), str);
 		g_free (str);
 		gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
-		gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+		gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
 		
 		label = gtk_label_new ("");
 		str = g_strdup_printf ("<b>%s:</b>", _("Specifications"));
 		gtk_label_set_markup (GTK_LABEL (label), str);
 		g_free (str);
 		gtk_misc_set_alignment (GTK_MISC (label), 0., 0.);
-		gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+		gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
 		
 		entry = gtk_entry_new ();
-		gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1, GTK_EXPAND | GTK_FILL, GTK_SHRINK, 0, 0);
+		gtk_grid_attach (GTK_GRID (grid), entry, 1, 0, 1, 1);
 		tsel->priv->properties_name = entry;
 		g_signal_connect (entry, "changed",
 				  G_CALLBACK (property_changed_cb), tsel);
@@ -335,7 +336,7 @@ properties_activated_cb (GtkMenuItem *mitem, DataFavoriteSelector *tsel)
 		sw = gtk_scrolled_window_new (NULL, NULL);
 		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 						GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-		gtk_table_attach_defaults (GTK_TABLE (table), sw, 1, 2, 1, 2);
+		gtk_grid_attach (GTK_GRID (grid), sw, 1, 1, 1, 1);
 		gtk_container_add (GTK_CONTAINER (sw), text);
 		tsel->priv->properties_text = text;
 		g_signal_connect (gtk_text_view_get_buffer (GTK_TEXT_VIEW (text)), "changed",
@@ -465,7 +466,7 @@ data_favorite_selector_new (BrowserConnection *bcnc)
 	
 	/* create tree managers */
 	tsel->priv->tree = gda_tree_new ();
-	manager = mgr_favorites_new (bcnc, TOOLS_FAVORITES_DATA_MANAGERS, ORDER_KEY_DATA_MANAGERS);
+	manager = mgr_favorites_new (bcnc, GDA_TOOLS_FAVORITES_DATA_MANAGERS, ORDER_KEY_DATA_MANAGERS);
         gda_tree_add_manager (tsel->priv->tree, manager);
 	g_object_unref (manager);
 
@@ -479,9 +480,9 @@ data_favorite_selector_new (BrowserConnection *bcnc)
 	GtkWidget *label;
 	gchar *str;
 	str = g_strdup_printf ("<b>%s</b>", _("Saved"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
-	cc_gray_bar_set_icon_from_pixbuf (CC_GRAY_BAR (label), browser_get_pixbuf_icon (BROWSER_ICON_BOOKMARK));
+	gdaui_bar_set_icon_from_pixbuf (GDAUI_BAR (label), browser_get_pixbuf_icon (BROWSER_ICON_BOOKMARK));
         gtk_box_pack_start (GTK_BOX (tsel), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
 
@@ -598,12 +599,12 @@ tree_store_drag_drop_cb (G_GNUC_UNUSED GdauiTreeStore *store, const gchar *path,
 	gint id;
 	bfav = browser_connection_get_favorites (tsel->priv->bcnc);
 
-	id = tools_favorites_find (bfav, 0, (gchar*) gtk_selection_data_get_data (selection_data),
+	id = gda_tools_favorites_find (bfav, 0, (gchar*) gtk_selection_data_get_data (selection_data),
 				     &fav, NULL);
 	if (id < 0) {
 		memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
 		fav.id = -1;
-		fav.type = TOOLS_FAVORITES_DATA_MANAGERS;
+		fav.type = GDA_TOOLS_FAVORITES_DATA_MANAGERS;
 		fav.name = _("Unnamed data manager");
 		fav.descr = NULL;
 		fav.contents = (gchar*) gtk_selection_data_get_data (selection_data);
@@ -612,7 +613,7 @@ tree_store_drag_drop_cb (G_GNUC_UNUSED GdauiTreeStore *store, const gchar *path,
 	pos = atoi (path);
 	/*g_print ("%s() path => %s, pos: %d\n", __FUNCTION__, path, pos);*/
 	
-	if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_DATA_MANAGERS, pos, &error)) {
+	if (! gda_tools_favorites_add (bfav, 0, &fav, ORDER_KEY_DATA_MANAGERS, pos, &error)) {
 		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tsel),
 				    _("Could not add favorite: %s"),
 				    error && error->message ? error->message : _("No detail"));
@@ -622,7 +623,7 @@ tree_store_drag_drop_cb (G_GNUC_UNUSED GdauiTreeStore *store, const gchar *path,
 	}
 	
 	if (id >= 0)
-		tools_favorites_reset_attributes (&fav);
+		gda_tools_favorites_reset_attributes (&fav);
 
 	return retval;
 }
